#[repr(u16)]pub enum LonghandId {
Show 298 variants
AlignItems = 0,
AlignmentBaseline = 1,
BackfaceVisibility = 2,
BaselineSource = 3,
BorderCollapse = 4,
BorderImageRepeat = 5,
BoxDecorationBreak = 6,
BoxSizing = 7,
CaptionSide = 8,
Clear = 9,
ColumnSpan = 10,
Contain = 11,
ContainerType = 12,
Direction = 13,
Display = 14,
EmptyCells = 15,
FillRule = 16,
FlexDirection = 17,
FlexWrap = 18,
Float = 19,
FontKerning = 20,
FontLanguageOverride = 21,
FontOpticalSizing = 22,
FontSynthesisWeight = 23,
FontVariantCaps = 24,
FontVariantEastAsian = 25,
FontVariantLigatures = 26,
FontVariantNumeric = 27,
FontVariantPosition = 28,
ForcedColorAdjust = 29,
GridAutoFlow = 30,
ImageRendering = 31,
Isolation = 32,
JustifyItems = 33,
LineBreak = 34,
ListStylePosition = 35,
MaskType = 36,
MathStyle = 37,
MixBlendMode = 38,
ObjectFit = 39,
OutlineStyle = 40,
OverflowWrap = 41,
PointerEvents = 42,
Position = 43,
PositionArea = 44,
ScrollBehavior = 45,
ScrollbarWidth = 46,
ServoTopLayer = 47,
StrokeLinecap = 48,
StrokeLinejoin = 49,
TableLayout = 50,
TextAlign = 51,
TextAlignLast = 52,
TextDecorationLine = 53,
TextDecorationStyle = 54,
TextJustify = 55,
TextOrientation = 56,
TextRendering = 57,
TextTransform = 58,
TextUnderlinePosition = 59,
TextWrapMode = 60,
TouchAction = 61,
TransformStyle = 62,
UnicodeBidi = 63,
UserSelect = 64,
Visibility = 65,
WebkitTextSecurity = 66,
WhiteSpaceCollapse = 67,
WordBreak = 68,
WritingMode = 69,
XTextScale = 70,
Appearance = 71,
MozDefaultAppearance = 72,
AlignContent = 73,
JustifyContent = 74,
AlignSelf = 75,
JustifySelf = 76,
OverflowBlock = 77,
OverflowInline = 78,
OverflowX = 79,
OverflowY = 80,
OverscrollBehaviorBlock = 81,
OverscrollBehaviorInline = 82,
OverscrollBehaviorX = 83,
OverscrollBehaviorY = 84,
BorderBlockEndStyle = 85,
BorderBlockStartStyle = 86,
BorderBottomStyle = 87,
BorderInlineEndStyle = 88,
BorderInlineStartStyle = 89,
BorderLeftStyle = 90,
BorderRightStyle = 91,
BorderTopStyle = 92,
AnimationComposition = 93,
AnimationDelay = 94,
AnimationDirection = 95,
AnimationDuration = 96,
AnimationFillMode = 97,
AnimationIterationCount = 98,
AnimationName = 99,
AnimationPlayState = 100,
AnimationRangeEnd = 101,
AnimationRangeStart = 102,
AnimationTimeline = 103,
AnimationTimingFunction = 104,
AspectRatio = 105,
BackdropFilter = 106,
BackgroundAttachment = 107,
BackgroundBlendMode = 108,
BackgroundClip = 109,
BackgroundImage = 110,
BackgroundOrigin = 111,
BackgroundPositionX = 112,
BackgroundPositionY = 113,
BackgroundRepeat = 114,
BackgroundSize = 115,
BaselineShift = 116,
BorderImageOutset = 117,
BorderImageSlice = 118,
BorderImageWidth = 119,
BorderSpacing = 120,
BoxShadow = 121,
CaretColor = 122,
Clip = 123,
ClipPath = 124,
Color = 125,
ColorScheme = 126,
ColumnCount = 127,
ColumnWidth = 128,
ContainerName = 129,
Content = 130,
CounterIncrement = 131,
CounterReset = 132,
Cursor = 133,
D = 134,
Filter = 135,
FlexBasis = 136,
FontFamily = 137,
FontFeatureSettings = 138,
FontSize = 139,
FontSizeAdjust = 140,
FontStyle = 141,
FontVariantAlternates = 142,
FontVariationSettings = 143,
FontWeight = 144,
FontWidth = 145,
GridTemplateAreas = 146,
LetterSpacing = 147,
LineHeight = 148,
ListStyleType = 149,
MaskClip = 150,
MaskComposite = 151,
MaskImage = 152,
MaskMode = 153,
MaskOrigin = 154,
MaskPositionX = 155,
MaskPositionY = 156,
MaskRepeat = 157,
MaskSize = 158,
MathDepth = 159,
MozMinFontSizeRatio = 160,
OffsetPath = 161,
Opacity = 162,
OutlineOffset = 163,
OverflowClipMargin = 164,
Perspective = 165,
PositionTryFallbacks = 166,
Quotes = 167,
Rotate = 168,
Scale = 169,
ScrollbarColor = 170,
StrokeDasharray = 171,
StrokeDashoffset = 172,
StrokeWidth = 173,
TabSize = 174,
TextDecorationInset = 175,
TextDecorationThickness = 176,
TextIndent = 177,
TextOverflow = 178,
TextShadow = 179,
TextUnderlineOffset = 180,
Transform = 181,
TransformOrigin = 182,
TransitionBehavior = 183,
TransitionDelay = 184,
TransitionDuration = 185,
TransitionProperty = 186,
TransitionTimingFunction = 187,
Translate = 188,
ViewTransitionClass = 189,
ViewTransitionName = 190,
WillChange = 191,
WordSpacing = 192,
XLang = 193,
ZIndex = 194,
Zoom = 195,
ObjectPosition = 196,
PerspectiveOrigin = 197,
Fill = 198,
Stroke = 199,
GridTemplateColumns = 200,
GridTemplateRows = 201,
BorderImageSource = 202,
ListStyleImage = 203,
GridAutoColumns = 204,
GridAutoRows = 205,
FlexLineCount = 206,
Order = 207,
Rx = 208,
Ry = 209,
FillOpacity = 210,
StrokeOpacity = 211,
ColumnGap = 212,
RowGap = 213,
FlexGrow = 214,
FlexShrink = 215,
StrokeMiterlimit = 216,
GridColumnEnd = 217,
GridColumnStart = 218,
GridRowEnd = 219,
GridRowStart = 220,
Cx = 221,
Cy = 222,
X = 223,
Y = 224,
MaxBlockSize = 225,
MaxHeight = 226,
MaxInlineSize = 227,
MaxWidth = 228,
BorderBottomLeftRadius = 229,
BorderBottomRightRadius = 230,
BorderEndEndRadius = 231,
BorderEndStartRadius = 232,
BorderStartEndRadius = 233,
BorderStartStartRadius = 234,
BorderTopLeftRadius = 235,
BorderTopRightRadius = 236,
CornerBottomLeftShape = 237,
CornerBottomRightShape = 238,
CornerEndEndShape = 239,
CornerEndStartShape = 240,
CornerStartEndShape = 241,
CornerStartStartShape = 242,
CornerTopLeftShape = 243,
CornerTopRightShape = 244,
Bottom = 245,
InsetBlockEnd = 246,
InsetBlockStart = 247,
InsetInlineEnd = 248,
InsetInlineStart = 249,
Left = 250,
Right = 251,
Top = 252,
MarginBlockEnd = 253,
MarginBlockStart = 254,
MarginBottom = 255,
MarginInlineEnd = 256,
MarginInlineStart = 257,
MarginLeft = 258,
MarginRight = 259,
MarginTop = 260,
BlockSize = 261,
Height = 262,
InlineSize = 263,
MinBlockSize = 264,
MinHeight = 265,
MinInlineSize = 266,
MinWidth = 267,
Width = 268,
BorderBlockEndWidth = 269,
BorderBlockStartWidth = 270,
BorderBottomWidth = 271,
BorderInlineEndWidth = 272,
BorderInlineStartWidth = 273,
BorderLeftWidth = 274,
BorderRightWidth = 275,
BorderTopWidth = 276,
OutlineWidth = 277,
PaddingBlockEnd = 278,
PaddingBlockStart = 279,
PaddingBottom = 280,
PaddingInlineEnd = 281,
PaddingInlineStart = 282,
PaddingLeft = 283,
PaddingRight = 284,
PaddingTop = 285,
R = 286,
BackgroundColor = 287,
BorderBlockEndColor = 288,
BorderBlockStartColor = 289,
BorderBottomColor = 290,
BorderInlineEndColor = 291,
BorderInlineStartColor = 292,
BorderLeftColor = 293,
BorderRightColor = 294,
BorderTopColor = 295,
OutlineColor = 296,
TextDecorationColor = 297,
}Expand description
An identifier for a given longhand property.
Variants
AlignItems = 0
align-items
AlignmentBaseline = 1
alignment-baseline
BackfaceVisibility = 2
backface-visibility
BaselineSource = 3
baseline-source
BorderCollapse = 4
border-collapse
BorderImageRepeat = 5
border-image-repeat
BoxDecorationBreak = 6
box-decoration-break
BoxSizing = 7
box-sizing
CaptionSide = 8
caption-side
Clear = 9
clear
ColumnSpan = 10
column-span
Contain = 11
contain
ContainerType = 12
container-type
Direction = 13
direction
Display = 14
display
EmptyCells = 15
empty-cells
FillRule = 16
fill-rule
FlexDirection = 17
flex-direction
FlexWrap = 18
flex-wrap
Float = 19
float
FontKerning = 20
font-kerning
FontLanguageOverride = 21
font-language-override
FontOpticalSizing = 22
font-optical-sizing
FontSynthesisWeight = 23
font-synthesis-weight
FontVariantCaps = 24
font-variant-caps
FontVariantEastAsian = 25
font-variant-east-asian
FontVariantLigatures = 26
font-variant-ligatures
FontVariantNumeric = 27
font-variant-numeric
FontVariantPosition = 28
font-variant-position
ForcedColorAdjust = 29
forced-color-adjust
GridAutoFlow = 30
grid-auto-flow
ImageRendering = 31
image-rendering
Isolation = 32
isolation
JustifyItems = 33
justify-items
LineBreak = 34
line-break
ListStylePosition = 35
list-style-position
MaskType = 36
mask-type
MathStyle = 37
math-style
MixBlendMode = 38
mix-blend-mode
ObjectFit = 39
object-fit
OutlineStyle = 40
outline-style
OverflowWrap = 41
overflow-wrap
PointerEvents = 42
pointer-events
Position = 43
position
PositionArea = 44
position-area
ScrollBehavior = 45
scroll-behavior
ScrollbarWidth = 46
scrollbar-width
ServoTopLayer = 47
-servo-top-layer
StrokeLinecap = 48
stroke-linecap
StrokeLinejoin = 49
stroke-linejoin
TableLayout = 50
table-layout
TextAlign = 51
text-align
TextAlignLast = 52
text-align-last
TextDecorationLine = 53
text-decoration-line
TextDecorationStyle = 54
text-decoration-style
TextJustify = 55
text-justify
TextOrientation = 56
text-orientation
TextRendering = 57
text-rendering
TextTransform = 58
text-transform
TextUnderlinePosition = 59
text-underline-position
TextWrapMode = 60
text-wrap-mode
TouchAction = 61
touch-action
TransformStyle = 62
transform-style
UnicodeBidi = 63
unicode-bidi
UserSelect = 64
user-select
Visibility = 65
visibility
WebkitTextSecurity = 66
-webkit-text-security
WhiteSpaceCollapse = 67
white-space-collapse
WordBreak = 68
word-break
WritingMode = 69
writing-mode
XTextScale = 70
-x-text-scale
Appearance = 71
appearance
MozDefaultAppearance = 72
-moz-default-appearance
AlignContent = 73
align-content
JustifyContent = 74
justify-content
AlignSelf = 75
align-self
JustifySelf = 76
justify-self
OverflowBlock = 77
overflow-block
OverflowInline = 78
overflow-inline
OverflowX = 79
overflow-x
OverflowY = 80
overflow-y
OverscrollBehaviorBlock = 81
overscroll-behavior-block
OverscrollBehaviorInline = 82
overscroll-behavior-inline
OverscrollBehaviorX = 83
overscroll-behavior-x
OverscrollBehaviorY = 84
overscroll-behavior-y
BorderBlockEndStyle = 85
border-block-end-style
BorderBlockStartStyle = 86
border-block-start-style
BorderBottomStyle = 87
border-bottom-style
BorderInlineEndStyle = 88
border-inline-end-style
BorderInlineStartStyle = 89
border-inline-start-style
BorderLeftStyle = 90
border-left-style
BorderRightStyle = 91
border-right-style
BorderTopStyle = 92
border-top-style
AnimationComposition = 93
animation-composition
AnimationDelay = 94
animation-delay
AnimationDirection = 95
animation-direction
AnimationDuration = 96
animation-duration
AnimationFillMode = 97
animation-fill-mode
AnimationIterationCount = 98
animation-iteration-count
AnimationName = 99
animation-name
AnimationPlayState = 100
animation-play-state
AnimationRangeEnd = 101
animation-range-end
AnimationRangeStart = 102
animation-range-start
AnimationTimeline = 103
animation-timeline
AnimationTimingFunction = 104
animation-timing-function
AspectRatio = 105
aspect-ratio
BackdropFilter = 106
backdrop-filter
BackgroundAttachment = 107
background-attachment
BackgroundBlendMode = 108
background-blend-mode
BackgroundClip = 109
background-clip
BackgroundImage = 110
background-image
BackgroundOrigin = 111
background-origin
BackgroundPositionX = 112
background-position-x
BackgroundPositionY = 113
background-position-y
BackgroundRepeat = 114
background-repeat
BackgroundSize = 115
background-size
BaselineShift = 116
baseline-shift
BorderImageOutset = 117
border-image-outset
BorderImageSlice = 118
border-image-slice
BorderImageWidth = 119
border-image-width
BorderSpacing = 120
border-spacing
BoxShadow = 121
box-shadow
CaretColor = 122
caret-color
Clip = 123
clip
ClipPath = 124
clip-path
Color = 125
color
ColorScheme = 126
color-scheme
ColumnCount = 127
column-count
ColumnWidth = 128
column-width
ContainerName = 129
container-name
Content = 130
content
CounterIncrement = 131
counter-increment
CounterReset = 132
counter-reset
Cursor = 133
cursor
D = 134
d
Filter = 135
filter
FlexBasis = 136
flex-basis
FontFamily = 137
font-family
FontFeatureSettings = 138
font-feature-settings
FontSize = 139
font-size
FontSizeAdjust = 140
font-size-adjust
FontStyle = 141
font-style
FontVariantAlternates = 142
font-variant-alternates
FontVariationSettings = 143
font-variation-settings
FontWeight = 144
font-weight
FontWidth = 145
font-width
GridTemplateAreas = 146
grid-template-areas
LetterSpacing = 147
letter-spacing
LineHeight = 148
line-height
ListStyleType = 149
list-style-type
MaskClip = 150
mask-clip
MaskComposite = 151
mask-composite
MaskImage = 152
mask-image
MaskMode = 153
mask-mode
MaskOrigin = 154
mask-origin
MaskPositionX = 155
mask-position-x
MaskPositionY = 156
mask-position-y
MaskRepeat = 157
mask-repeat
MaskSize = 158
mask-size
MathDepth = 159
math-depth
MozMinFontSizeRatio = 160
-moz-min-font-size-ratio
OffsetPath = 161
offset-path
Opacity = 162
opacity
OutlineOffset = 163
outline-offset
OverflowClipMargin = 164
overflow-clip-margin
Perspective = 165
perspective
PositionTryFallbacks = 166
position-try-fallbacks
Quotes = 167
quotes
Rotate = 168
rotate
Scale = 169
scale
ScrollbarColor = 170
scrollbar-color
StrokeDasharray = 171
stroke-dasharray
StrokeDashoffset = 172
stroke-dashoffset
StrokeWidth = 173
stroke-width
TabSize = 174
tab-size
TextDecorationInset = 175
text-decoration-inset
TextDecorationThickness = 176
text-decoration-thickness
TextIndent = 177
text-indent
TextOverflow = 178
text-overflow
TextShadow = 179
text-shadow
TextUnderlineOffset = 180
text-underline-offset
Transform = 181
transform
TransformOrigin = 182
transform-origin
TransitionBehavior = 183
transition-behavior
TransitionDelay = 184
transition-delay
TransitionDuration = 185
transition-duration
TransitionProperty = 186
transition-property
TransitionTimingFunction = 187
transition-timing-function
Translate = 188
translate
ViewTransitionClass = 189
view-transition-class
ViewTransitionName = 190
view-transition-name
WillChange = 191
will-change
WordSpacing = 192
word-spacing
XLang = 193
-x-lang
ZIndex = 194
z-index
Zoom = 195
zoom
ObjectPosition = 196
object-position
PerspectiveOrigin = 197
perspective-origin
Fill = 198
fill
Stroke = 199
stroke
GridTemplateColumns = 200
grid-template-columns
GridTemplateRows = 201
grid-template-rows
BorderImageSource = 202
border-image-source
ListStyleImage = 203
list-style-image
GridAutoColumns = 204
grid-auto-columns
GridAutoRows = 205
grid-auto-rows
FlexLineCount = 206
flex-line-count
Order = 207
order
Rx = 208
rx
Ry = 209
ry
FillOpacity = 210
fill-opacity
StrokeOpacity = 211
stroke-opacity
ColumnGap = 212
column-gap
RowGap = 213
row-gap
FlexGrow = 214
flex-grow
FlexShrink = 215
flex-shrink
StrokeMiterlimit = 216
stroke-miterlimit
GridColumnEnd = 217
grid-column-end
GridColumnStart = 218
grid-column-start
GridRowEnd = 219
grid-row-end
GridRowStart = 220
grid-row-start
Cx = 221
cx
Cy = 222
cy
X = 223
x
Y = 224
y
MaxBlockSize = 225
max-block-size
MaxHeight = 226
max-height
MaxInlineSize = 227
max-inline-size
MaxWidth = 228
max-width
BorderBottomLeftRadius = 229
border-bottom-left-radius
BorderBottomRightRadius = 230
border-bottom-right-radius
BorderEndEndRadius = 231
border-end-end-radius
BorderEndStartRadius = 232
border-end-start-radius
BorderStartEndRadius = 233
border-start-end-radius
BorderStartStartRadius = 234
border-start-start-radius
BorderTopLeftRadius = 235
border-top-left-radius
BorderTopRightRadius = 236
border-top-right-radius
CornerBottomLeftShape = 237
corner-bottom-left-shape
CornerBottomRightShape = 238
corner-bottom-right-shape
CornerEndEndShape = 239
corner-end-end-shape
CornerEndStartShape = 240
corner-end-start-shape
CornerStartEndShape = 241
corner-start-end-shape
CornerStartStartShape = 242
corner-start-start-shape
CornerTopLeftShape = 243
corner-top-left-shape
CornerTopRightShape = 244
corner-top-right-shape
Bottom = 245
bottom
InsetBlockEnd = 246
inset-block-end
InsetBlockStart = 247
inset-block-start
InsetInlineEnd = 248
inset-inline-end
InsetInlineStart = 249
inset-inline-start
Left = 250
left
Right = 251
right
Top = 252
top
MarginBlockEnd = 253
margin-block-end
MarginBlockStart = 254
margin-block-start
MarginBottom = 255
margin-bottom
MarginInlineEnd = 256
margin-inline-end
MarginInlineStart = 257
margin-inline-start
MarginLeft = 258
margin-left
MarginRight = 259
margin-right
MarginTop = 260
margin-top
BlockSize = 261
block-size
Height = 262
height
InlineSize = 263
inline-size
MinBlockSize = 264
min-block-size
MinHeight = 265
min-height
MinInlineSize = 266
min-inline-size
MinWidth = 267
min-width
Width = 268
width
BorderBlockEndWidth = 269
border-block-end-width
BorderBlockStartWidth = 270
border-block-start-width
BorderBottomWidth = 271
border-bottom-width
BorderInlineEndWidth = 272
border-inline-end-width
BorderInlineStartWidth = 273
border-inline-start-width
BorderLeftWidth = 274
border-left-width
BorderRightWidth = 275
border-right-width
BorderTopWidth = 276
border-top-width
OutlineWidth = 277
outline-width
PaddingBlockEnd = 278
padding-block-end
PaddingBlockStart = 279
padding-block-start
PaddingBottom = 280
padding-bottom
PaddingInlineEnd = 281
padding-inline-end
PaddingInlineStart = 282
padding-inline-start
PaddingLeft = 283
padding-left
PaddingRight = 284
padding-right
PaddingTop = 285
padding-top
R = 286
r
BackgroundColor = 287
background-color
BorderBlockEndColor = 288
border-block-end-color
BorderBlockStartColor = 289
border-block-start-color
BorderBottomColor = 290
border-bottom-color
BorderInlineEndColor = 291
border-inline-end-color
BorderInlineStartColor = 292
border-inline-start-color
BorderLeftColor = 293
border-left-color
BorderRightColor = 294
border-right-color
BorderTopColor = 295
border-top-color
OutlineColor = 296
outline-color
TextDecorationColor = 297
text-decoration-color
Implementations
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
Returns an iterator over all the shorthands that include this longhand.
pub(super) fn parse_value( self, context: &ParserContext<'_>, input: &mut Parser<'_>, ) -> Result<PropertyDeclaration, ParseError>
Sourcefn logical_mapping_data(self) -> Option<&'static LogicalMappingData>
fn logical_mapping_data(self) -> Option<&'static LogicalMappingData>
Return the relevant data to map a particular logical property into physical.
Sourcepub fn to_physical(self, wm: WritingMode) -> Self
pub fn to_physical(self, wm: WritingMode) -> Self
If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.
Sourcepub fn logical_group(self) -> Option<LogicalGroupId>
pub fn logical_group(self) -> Option<LogicalGroupId>
Return the logical group of this longhand property.
Sourcepub fn flags(self) -> PropertyFlags
pub fn flags(self) -> PropertyFlags
Returns PropertyFlags for given longhand property.
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn zoom_dependent(self) -> bool
pub fn zoom_dependent(self) -> bool
Returns whether the longhand property is zoom-dependent.
Sourcepub fn ignored_when_document_colors_disabled(self) -> bool
pub fn ignored_when_document_colors_disabled(self) -> bool
Returns true if the property is one that is ignored when document colors are disabled.
Sourcepub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
Returns whether this longhand is non_custom or is a longhand of it.
Sourcepub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
Returns whether this longhand is a longhand of shorthand.
Sourcepub fn is_animatable(self) -> bool
pub fn is_animatable(self) -> bool
Returns whether this property is animatable.
Sourcepub fn is_discrete_animatable(self) -> bool
pub fn is_discrete_animatable(self) -> bool
Returns whether this property is animatable in a discrete way.
Sourcepub fn is_logical(self) -> bool
pub fn is_logical(self) -> bool
Return whether this property is logical.