PrioritaryPropertyId

Enum PrioritaryPropertyId 

#[repr(u8)]
pub enum PrioritaryPropertyId {
Show 19 variants Direction = 0, ForcedColorAdjust = 1, TextOrientation = 2, WritingMode = 3, XTextScale = 4, Appearance = 5, MozDefaultAppearance = 6, ColorScheme = 7, FontFamily = 8, FontSize = 9, FontSizeAdjust = 10, FontStretch = 11, FontStyle = 12, FontWeight = 13, LineHeight = 14, MathDepth = 15, MozMinFontSizeRatio = 16, XLang = 17, Zoom = 18,
}
An id of a property that can be depended on by other properties.

Variants



Direction = 0



ForcedColorAdjust = 1



TextOrientation = 2



WritingMode = 3



XTextScale = 4



Appearance = 5



MozDefaultAppearance = 6



ColorScheme = 7



FontFamily = 8



FontSize = 9



FontSizeAdjust = 10



FontStretch = 11



FontStyle = 12



FontWeight = 13



LineHeight = 14



MathDepth = 15



MozMinFontSizeRatio = 16



XLang = 17



Zoom = 18

Implementations

Source

impl PrioritaryPropertyId

pub fn each() -> impl Iterator<Item = Self>

Iterates over all prioritary properties, in declaration (longhand) order.

pub fn to_longhand(self) -> LonghandId

Converts a PrioritaryPropertyId to a LonghandId.

pub fn from_longhand(l: LonghandId) -> Option<Self>

Converts a LonghandId to a PrioritaryPropertyId.

pub fn dependencies(self) -> &'static PrioritaryPropertyIdSet

Returns the set of prioritary properties that must be applied before this one, i.e. the properties it depends on.