LonghandId

Enum LonghandId 

#[repr(u16)]
pub enum LonghandId {
Show 256 variants AlignItems = 0, AlignmentBaseline = 1, BackfaceVisibility = 2, BaselineSource = 3, BorderCollapse = 4, BorderImageRepeat = 5, BoxSizing = 6, CaptionSide = 7, Clear = 8, ColumnSpan = 9, Contain = 10, ContainerType = 11, Direction = 12, Display = 13, EmptyCells = 14, FlexDirection = 15, FlexWrap = 16, Float = 17, FontKerning = 18, FontLanguageOverride = 19, FontOpticalSizing = 20, FontSynthesisWeight = 21, FontVariantCaps = 22, FontVariantEastAsian = 23, FontVariantLigatures = 24, FontVariantNumeric = 25, FontVariantPosition = 26, GridAutoFlow = 27, ImageRendering = 28, Isolation = 29, JustifyItems = 30, LineBreak = 31, ListStylePosition = 32, MaskType = 33, MixBlendMode = 34, ObjectFit = 35, OutlineStyle = 36, OverflowWrap = 37, PointerEvents = 38, Position = 39, PositionArea = 40, ServoTopLayer = 41, TableLayout = 42, TextAlign = 43, TextAlignLast = 44, TextDecorationLine = 45, TextDecorationStyle = 46, TextJustify = 47, TextRendering = 48, TextTransform = 49, TextWrapMode = 50, TouchAction = 51, TransformStyle = 52, UnicodeBidi = 53, UserSelect = 54, Visibility = 55, WebkitTextSecurity = 56, WhiteSpaceCollapse = 57, WordBreak = 58, WritingMode = 59, AlignContent = 60, JustifyContent = 61, AlignSelf = 62, JustifySelf = 63, OverflowBlock = 64, OverflowInline = 65, OverflowX = 66, OverflowY = 67, BorderBlockEndStyle = 68, BorderBlockStartStyle = 69, BorderBottomStyle = 70, BorderInlineEndStyle = 71, BorderInlineStartStyle = 72, BorderLeftStyle = 73, BorderRightStyle = 74, BorderTopStyle = 75, AnimationComposition = 76, AnimationDelay = 77, AnimationDirection = 78, AnimationDuration = 79, AnimationFillMode = 80, AnimationIterationCount = 81, AnimationName = 82, AnimationPlayState = 83, AnimationRangeEnd = 84, AnimationRangeStart = 85, AnimationTimeline = 86, AnimationTimingFunction = 87, AspectRatio = 88, BackdropFilter = 89, BackgroundAttachment = 90, BackgroundBlendMode = 91, BackgroundClip = 92, BackgroundImage = 93, BackgroundOrigin = 94, BackgroundPositionX = 95, BackgroundPositionY = 96, BackgroundRepeat = 97, BackgroundSize = 98, BaselineShift = 99, BorderImageOutset = 100, BorderImageSlice = 101, BorderImageWidth = 102, BorderSpacing = 103, BoxShadow = 104, CaretColor = 105, Clip = 106, ClipPath = 107, Color = 108, ColorScheme = 109, ColumnCount = 110, ColumnWidth = 111, ContainerName = 112, Content = 113, CounterIncrement = 114, CounterReset = 115, Cursor = 116, Filter = 117, FlexBasis = 118, FontFamily = 119, FontFeatureSettings = 120, FontSize = 121, FontStretch = 122, FontStyle = 123, FontVariationSettings = 124, FontWeight = 125, GridTemplateAreas = 126, LetterSpacing = 127, LineHeight = 128, ListStyleType = 129, MaskClip = 130, MaskComposite = 131, MaskImage = 132, MaskMode = 133, MaskOrigin = 134, MaskPositionX = 135, MaskPositionY = 136, MaskRepeat = 137, MaskSize = 138, OffsetPath = 139, Opacity = 140, Order = 141, OutlineOffset = 142, OverflowClipMargin = 143, Perspective = 144, PositionTryFallbacks = 145, Quotes = 146, Rotate = 147, Scale = 148, TabSize = 149, TextIndent = 150, TextOverflow = 151, TextShadow = 152, Transform = 153, TransformOrigin = 154, TransitionBehavior = 155, TransitionDelay = 156, TransitionDuration = 157, TransitionProperty = 158, TransitionTimingFunction = 159, Translate = 160, ViewTransitionClass = 161, ViewTransitionName = 162, WillChange = 163, WordSpacing = 164, XLang = 165, ZIndex = 166, Zoom = 167, ObjectPosition = 168, PerspectiveOrigin = 169, GridTemplateColumns = 170, GridTemplateRows = 171, BorderImageSource = 172, ListStyleImage = 173, GridAutoColumns = 174, GridAutoRows = 175, FlexGrow = 176, FlexShrink = 177, ColumnGap = 178, RowGap = 179, GridColumnEnd = 180, GridColumnStart = 181, GridRowEnd = 182, GridRowStart = 183, MaxBlockSize = 184, MaxHeight = 185, MaxInlineSize = 186, MaxWidth = 187, BorderBottomLeftRadius = 188, BorderBottomRightRadius = 189, BorderEndEndRadius = 190, BorderEndStartRadius = 191, BorderStartEndRadius = 192, BorderStartStartRadius = 193, BorderTopLeftRadius = 194, BorderTopRightRadius = 195, CornerBottomLeftShape = 196, CornerBottomRightShape = 197, CornerEndEndShape = 198, CornerEndStartShape = 199, CornerStartEndShape = 200, CornerStartStartShape = 201, CornerTopLeftShape = 202, CornerTopRightShape = 203, Bottom = 204, InsetBlockEnd = 205, InsetBlockStart = 206, InsetInlineEnd = 207, InsetInlineStart = 208, Left = 209, Right = 210, Top = 211, MarginBlockEnd = 212, MarginBlockStart = 213, MarginBottom = 214, MarginInlineEnd = 215, MarginInlineStart = 216, MarginLeft = 217, MarginRight = 218, MarginTop = 219, PaddingBlockEnd = 220, PaddingBlockStart = 221, PaddingBottom = 222, PaddingInlineEnd = 223, PaddingInlineStart = 224, PaddingLeft = 225, PaddingRight = 226, PaddingTop = 227, BlockSize = 228, Height = 229, InlineSize = 230, MinBlockSize = 231, MinHeight = 232, MinInlineSize = 233, MinWidth = 234, Width = 235, BorderBlockEndWidth = 236, BorderBlockStartWidth = 237, BorderBottomWidth = 238, BorderInlineEndWidth = 239, BorderInlineStartWidth = 240, BorderLeftWidth = 241, BorderRightWidth = 242, BorderTopWidth = 243, OutlineWidth = 244, BackgroundColor = 245, BorderBlockEndColor = 246, BorderBlockStartColor = 247, BorderBottomColor = 248, BorderInlineEndColor = 249, BorderInlineStartColor = 250, BorderLeftColor = 251, BorderRightColor = 252, BorderTopColor = 253, OutlineColor = 254, TextDecorationColor = 255,
}
An identifier for a given longhand property.

Variants



AlignItems = 0

align-items



AlignmentBaseline = 1

alignment-baseline



BackfaceVisibility = 2

backface-visibility



BaselineSource = 3

baseline-source



BorderCollapse = 4

border-collapse



BorderImageRepeat = 5

border-image-repeat



BoxSizing = 6

box-sizing



CaptionSide = 7

caption-side



Clear = 8

clear



ColumnSpan = 9

column-span



Contain = 10

contain



ContainerType = 11

container-type



Direction = 12

direction



Display = 13

display



EmptyCells = 14

empty-cells



FlexDirection = 15

flex-direction



FlexWrap = 16

flex-wrap



Float = 17

float



FontKerning = 18

font-kerning



FontLanguageOverride = 19

font-language-override



FontOpticalSizing = 20

font-optical-sizing



FontSynthesisWeight = 21

font-synthesis-weight



FontVariantCaps = 22

font-variant-caps



FontVariantEastAsian = 23

font-variant-east-asian



FontVariantLigatures = 24

font-variant-ligatures



FontVariantNumeric = 25

font-variant-numeric



FontVariantPosition = 26

font-variant-position



GridAutoFlow = 27

grid-auto-flow



ImageRendering = 28

image-rendering



Isolation = 29

isolation



JustifyItems = 30

justify-items



LineBreak = 31

line-break



ListStylePosition = 32

list-style-position



MaskType = 33

mask-type



MixBlendMode = 34

mix-blend-mode



ObjectFit = 35

object-fit



OutlineStyle = 36

outline-style



OverflowWrap = 37

overflow-wrap



PointerEvents = 38

pointer-events



Position = 39

position



PositionArea = 40

position-area



ServoTopLayer = 41

-servo-top-layer



TableLayout = 42

table-layout



TextAlign = 43

text-align



TextAlignLast = 44

text-align-last



TextDecorationLine = 45

text-decoration-line



TextDecorationStyle = 46

text-decoration-style



TextJustify = 47

text-justify



TextRendering = 48

text-rendering



TextTransform = 49

text-transform



TextWrapMode = 50

text-wrap-mode



TouchAction = 51

touch-action



TransformStyle = 52

transform-style



UnicodeBidi = 53

unicode-bidi



UserSelect = 54

user-select



Visibility = 55

visibility



WebkitTextSecurity = 56

-webkit-text-security



WhiteSpaceCollapse = 57

white-space-collapse



WordBreak = 58

word-break



WritingMode = 59

writing-mode



AlignContent = 60

align-content



JustifyContent = 61

justify-content



AlignSelf = 62

align-self



JustifySelf = 63

justify-self



OverflowBlock = 64

overflow-block



OverflowInline = 65

overflow-inline



OverflowX = 66

overflow-x



OverflowY = 67

overflow-y



BorderBlockEndStyle = 68

border-block-end-style



BorderBlockStartStyle = 69

border-block-start-style



BorderBottomStyle = 70

border-bottom-style



BorderInlineEndStyle = 71

border-inline-end-style



BorderInlineStartStyle = 72

border-inline-start-style



BorderLeftStyle = 73

border-left-style



BorderRightStyle = 74

border-right-style



BorderTopStyle = 75

border-top-style



AnimationComposition = 76

animation-composition



AnimationDelay = 77

animation-delay



AnimationDirection = 78

animation-direction



AnimationDuration = 79

animation-duration



AnimationFillMode = 80

animation-fill-mode



AnimationIterationCount = 81

animation-iteration-count



AnimationName = 82

animation-name



AnimationPlayState = 83

animation-play-state



AnimationRangeEnd = 84

animation-range-end



AnimationRangeStart = 85

animation-range-start



AnimationTimeline = 86

animation-timeline



AnimationTimingFunction = 87

animation-timing-function



AspectRatio = 88

aspect-ratio



BackdropFilter = 89

backdrop-filter



BackgroundAttachment = 90

background-attachment



BackgroundBlendMode = 91

background-blend-mode



BackgroundClip = 92

background-clip



BackgroundImage = 93

background-image



BackgroundOrigin = 94

background-origin



BackgroundPositionX = 95

background-position-x



BackgroundPositionY = 96

background-position-y



BackgroundRepeat = 97

background-repeat



BackgroundSize = 98

background-size



BaselineShift = 99

baseline-shift



BorderImageOutset = 100

border-image-outset



BorderImageSlice = 101

border-image-slice



BorderImageWidth = 102

border-image-width



BorderSpacing = 103

border-spacing



BoxShadow = 104

box-shadow



CaretColor = 105

caret-color



Clip = 106

clip



ClipPath = 107

clip-path



Color = 108

color



ColorScheme = 109

color-scheme



ColumnCount = 110

column-count



ColumnWidth = 111

column-width



ContainerName = 112

container-name



Content = 113

content



CounterIncrement = 114

counter-increment



CounterReset = 115

counter-reset



Cursor = 116

cursor



Filter = 117

filter



FlexBasis = 118

flex-basis



FontFamily = 119

font-family



FontFeatureSettings = 120

font-feature-settings



FontSize = 121

font-size



FontStretch = 122

font-stretch



FontStyle = 123

font-style



FontVariationSettings = 124

font-variation-settings



FontWeight = 125

font-weight



GridTemplateAreas = 126

grid-template-areas



LetterSpacing = 127

letter-spacing



LineHeight = 128

line-height



ListStyleType = 129

list-style-type



MaskClip = 130

mask-clip



MaskComposite = 131

mask-composite



MaskImage = 132

mask-image



MaskMode = 133

mask-mode



MaskOrigin = 134

mask-origin



MaskPositionX = 135

mask-position-x



MaskPositionY = 136

mask-position-y



MaskRepeat = 137

mask-repeat



MaskSize = 138

mask-size



OffsetPath = 139

offset-path



Opacity = 140

opacity



Order = 141

order



OutlineOffset = 142

outline-offset



OverflowClipMargin = 143

overflow-clip-margin



Perspective = 144

perspective



PositionTryFallbacks = 145

position-try-fallbacks



Quotes = 146

quotes



Rotate = 147

rotate



Scale = 148

scale



TabSize = 149

tab-size



TextIndent = 150

text-indent



TextOverflow = 151

text-overflow



TextShadow = 152

text-shadow



Transform = 153

transform



TransformOrigin = 154

transform-origin



TransitionBehavior = 155

transition-behavior



TransitionDelay = 156

transition-delay



TransitionDuration = 157

transition-duration



TransitionProperty = 158

transition-property



TransitionTimingFunction = 159

transition-timing-function



Translate = 160

translate



ViewTransitionClass = 161

view-transition-class



ViewTransitionName = 162

view-transition-name



WillChange = 163

will-change



WordSpacing = 164

word-spacing



XLang = 165

-x-lang



ZIndex = 166

z-index



Zoom = 167

zoom



ObjectPosition = 168

object-position



PerspectiveOrigin = 169

perspective-origin



GridTemplateColumns = 170

grid-template-columns



GridTemplateRows = 171

grid-template-rows



BorderImageSource = 172

border-image-source



ListStyleImage = 173

list-style-image



GridAutoColumns = 174

grid-auto-columns



GridAutoRows = 175

grid-auto-rows



FlexGrow = 176

flex-grow



FlexShrink = 177

flex-shrink



ColumnGap = 178

column-gap



RowGap = 179

row-gap



GridColumnEnd = 180

grid-column-end



GridColumnStart = 181

grid-column-start



GridRowEnd = 182

grid-row-end



GridRowStart = 183

grid-row-start



MaxBlockSize = 184

max-block-size



MaxHeight = 185

max-height



MaxInlineSize = 186

max-inline-size



MaxWidth = 187

max-width



BorderBottomLeftRadius = 188

border-bottom-left-radius



BorderBottomRightRadius = 189

border-bottom-right-radius



BorderEndEndRadius = 190

border-end-end-radius



BorderEndStartRadius = 191

border-end-start-radius



BorderStartEndRadius = 192

border-start-end-radius



BorderStartStartRadius = 193

border-start-start-radius



BorderTopLeftRadius = 194

border-top-left-radius



BorderTopRightRadius = 195

border-top-right-radius



CornerBottomLeftShape = 196

corner-bottom-left-shape



CornerBottomRightShape = 197

corner-bottom-right-shape



CornerEndEndShape = 198

corner-end-end-shape



CornerEndStartShape = 199

corner-end-start-shape



CornerStartEndShape = 200

corner-start-end-shape



CornerStartStartShape = 201

corner-start-start-shape



CornerTopLeftShape = 202

corner-top-left-shape



CornerTopRightShape = 203

corner-top-right-shape



Bottom = 204

bottom



InsetBlockEnd = 205

inset-block-end



InsetBlockStart = 206

inset-block-start



InsetInlineEnd = 207

inset-inline-end



InsetInlineStart = 208

inset-inline-start



Left = 209

left



Right = 210

right



Top = 211

top



MarginBlockEnd = 212

margin-block-end



MarginBlockStart = 213

margin-block-start



MarginBottom = 214

margin-bottom



MarginInlineEnd = 215

margin-inline-end



MarginInlineStart = 216

margin-inline-start



MarginLeft = 217

margin-left



MarginRight = 218

margin-right



MarginTop = 219

margin-top



PaddingBlockEnd = 220

padding-block-end



PaddingBlockStart = 221

padding-block-start



PaddingBottom = 222

padding-bottom



PaddingInlineEnd = 223

padding-inline-end



PaddingInlineStart = 224

padding-inline-start



PaddingLeft = 225

padding-left



PaddingRight = 226

padding-right



PaddingTop = 227

padding-top



BlockSize = 228

block-size



Height = 229

height



InlineSize = 230

inline-size



MinBlockSize = 231

min-block-size



MinHeight = 232

min-height



MinInlineSize = 233

min-inline-size



MinWidth = 234

min-width



Width = 235

width



BorderBlockEndWidth = 236

border-block-end-width



BorderBlockStartWidth = 237

border-block-start-width



BorderBottomWidth = 238

border-bottom-width



BorderInlineEndWidth = 239

border-inline-end-width



BorderInlineStartWidth = 240

border-inline-start-width



BorderLeftWidth = 241

border-left-width



BorderRightWidth = 242

border-right-width



BorderTopWidth = 243

border-top-width



OutlineWidth = 244

outline-width



BackgroundColor = 245

background-color



BorderBlockEndColor = 246

border-block-end-color



BorderBlockStartColor = 247

border-block-start-color



BorderBottomColor = 248

border-bottom-color



BorderInlineEndColor = 249

border-inline-end-color



BorderInlineStartColor = 250

border-inline-start-color



BorderLeftColor = 251

border-left-color



BorderRightColor = 252

border-right-color



BorderTopColor = 253

border-top-color



OutlineColor = 254

outline-color



TextDecorationColor = 255

text-decoration-color

Implementations

Source

impl LonghandId

pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId>

Returns an iterator over all the shorthands that include this longhand.

pub(super) fn parse_value<'i, 't>( self, context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<PropertyDeclaration, ParseError<'i>>

fn logical_mapping_data(self) -> Option<&'static LogicalMappingData>

Return the relevant data to map a particular logical property into physical.

pub fn to_physical(self, wm: WritingMode) -> Self

If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.

pub fn logical_group(self) -> Option<LogicalGroupId>

Return the logical group of this longhand property.

pub fn flags(self) -> PropertyFlags

Returns PropertyFlags for given longhand property.

Source

impl LonghandId

pub fn name(&self) -> &'static str

Get the name of this longhand property.

pub fn inherited(self) -> bool

Returns whether the longhand property is inherited by default.

pub fn zoom_dependent(self) -> bool

Returns whether the longhand property is zoom-dependent.

pub fn ignored_when_document_colors_disabled(self) -> bool

Returns true if the property is one that is ignored when document colors are disabled.

pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool

Returns whether this longhand is non_custom or is a longhand of it.

pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool

Returns whether this longhand is a longhand of shorthand.

pub fn is_animatable(self) -> bool

Returns whether this property is animatable.

pub fn is_discrete_animatable(self) -> bool

Returns whether this property is animatable in a discrete way.

pub fn is_logical(self) -> bool

Return whether this property is logical.