LonghandId

Enum LonghandId 

#[repr(u16)]
pub enum LonghandId {
Show 255 variants AlignItems = 0, AlignmentBaseline = 1, BackfaceVisibility = 2, BaselineSource = 3, BorderCollapse = 4, BorderImageRepeat = 5, BoxSizing = 6, CaptionSide = 7, Clear = 8, ColumnSpan = 9, Contain = 10, ContainerType = 11, Direction = 12, Display = 13, EmptyCells = 14, FlexDirection = 15, FlexWrap = 16, Float = 17, FontKerning = 18, FontLanguageOverride = 19, FontOpticalSizing = 20, FontSynthesisWeight = 21, FontVariantCaps = 22, FontVariantEastAsian = 23, FontVariantLigatures = 24, FontVariantNumeric = 25, FontVariantPosition = 26, GridAutoFlow = 27, ImageRendering = 28, Isolation = 29, JustifyItems = 30, LineBreak = 31, ListStylePosition = 32, MaskType = 33, MixBlendMode = 34, ObjectFit = 35, OutlineStyle = 36, OverflowWrap = 37, PointerEvents = 38, Position = 39, PositionArea = 40, ServoTopLayer = 41, TableLayout = 42, TextAlign = 43, TextAlignLast = 44, TextDecorationLine = 45, TextDecorationStyle = 46, TextJustify = 47, TextRendering = 48, TextTransform = 49, TextWrapMode = 50, TransformStyle = 51, UnicodeBidi = 52, UserSelect = 53, Visibility = 54, WebkitTextSecurity = 55, WhiteSpaceCollapse = 56, WordBreak = 57, WritingMode = 58, AlignContent = 59, JustifyContent = 60, AlignSelf = 61, JustifySelf = 62, OverflowBlock = 63, OverflowInline = 64, OverflowX = 65, OverflowY = 66, BorderBlockEndStyle = 67, BorderBlockStartStyle = 68, BorderBottomStyle = 69, BorderInlineEndStyle = 70, BorderInlineStartStyle = 71, BorderLeftStyle = 72, BorderRightStyle = 73, BorderTopStyle = 74, AnimationComposition = 75, AnimationDelay = 76, AnimationDirection = 77, AnimationDuration = 78, AnimationFillMode = 79, AnimationIterationCount = 80, AnimationName = 81, AnimationPlayState = 82, AnimationRangeEnd = 83, AnimationRangeStart = 84, AnimationTimeline = 85, AnimationTimingFunction = 86, AspectRatio = 87, BackdropFilter = 88, BackgroundAttachment = 89, BackgroundBlendMode = 90, BackgroundClip = 91, BackgroundImage = 92, BackgroundOrigin = 93, BackgroundPositionX = 94, BackgroundPositionY = 95, BackgroundRepeat = 96, BackgroundSize = 97, BaselineShift = 98, BorderImageOutset = 99, BorderImageSlice = 100, BorderImageWidth = 101, BorderSpacing = 102, BoxShadow = 103, CaretColor = 104, Clip = 105, ClipPath = 106, Color = 107, ColorScheme = 108, ColumnCount = 109, ColumnWidth = 110, ContainerName = 111, Content = 112, CounterIncrement = 113, CounterReset = 114, Cursor = 115, Filter = 116, FlexBasis = 117, FontFamily = 118, FontFeatureSettings = 119, FontSize = 120, FontStretch = 121, FontStyle = 122, FontVariationSettings = 123, FontWeight = 124, GridTemplateAreas = 125, LetterSpacing = 126, LineHeight = 127, ListStyleType = 128, MaskClip = 129, MaskComposite = 130, MaskImage = 131, MaskMode = 132, MaskOrigin = 133, MaskPositionX = 134, MaskPositionY = 135, MaskRepeat = 136, MaskSize = 137, OffsetPath = 138, Opacity = 139, Order = 140, OutlineOffset = 141, OverflowClipMargin = 142, Perspective = 143, PositionTryFallbacks = 144, Quotes = 145, Rotate = 146, Scale = 147, TabSize = 148, TextIndent = 149, TextOverflow = 150, TextShadow = 151, Transform = 152, TransformOrigin = 153, TransitionBehavior = 154, TransitionDelay = 155, TransitionDuration = 156, TransitionProperty = 157, TransitionTimingFunction = 158, Translate = 159, ViewTransitionClass = 160, ViewTransitionName = 161, WillChange = 162, WordSpacing = 163, XLang = 164, ZIndex = 165, Zoom = 166, ObjectPosition = 167, PerspectiveOrigin = 168, GridTemplateColumns = 169, GridTemplateRows = 170, BorderImageSource = 171, ListStyleImage = 172, GridAutoColumns = 173, GridAutoRows = 174, FlexGrow = 175, FlexShrink = 176, ColumnGap = 177, RowGap = 178, GridColumnEnd = 179, GridColumnStart = 180, GridRowEnd = 181, GridRowStart = 182, MaxBlockSize = 183, MaxHeight = 184, MaxInlineSize = 185, MaxWidth = 186, BorderBottomLeftRadius = 187, BorderBottomRightRadius = 188, BorderEndEndRadius = 189, BorderEndStartRadius = 190, BorderStartEndRadius = 191, BorderStartStartRadius = 192, BorderTopLeftRadius = 193, BorderTopRightRadius = 194, CornerBottomLeftShape = 195, CornerBottomRightShape = 196, CornerEndEndShape = 197, CornerEndStartShape = 198, CornerStartEndShape = 199, CornerStartStartShape = 200, CornerTopLeftShape = 201, CornerTopRightShape = 202, Bottom = 203, InsetBlockEnd = 204, InsetBlockStart = 205, InsetInlineEnd = 206, InsetInlineStart = 207, Left = 208, Right = 209, Top = 210, MarginBlockEnd = 211, MarginBlockStart = 212, MarginBottom = 213, MarginInlineEnd = 214, MarginInlineStart = 215, MarginLeft = 216, MarginRight = 217, MarginTop = 218, PaddingBlockEnd = 219, PaddingBlockStart = 220, PaddingBottom = 221, PaddingInlineEnd = 222, PaddingInlineStart = 223, PaddingLeft = 224, PaddingRight = 225, PaddingTop = 226, BlockSize = 227, Height = 228, InlineSize = 229, MinBlockSize = 230, MinHeight = 231, MinInlineSize = 232, MinWidth = 233, Width = 234, BorderBlockEndWidth = 235, BorderBlockStartWidth = 236, BorderBottomWidth = 237, BorderInlineEndWidth = 238, BorderInlineStartWidth = 239, BorderLeftWidth = 240, BorderRightWidth = 241, BorderTopWidth = 242, OutlineWidth = 243, BackgroundColor = 244, BorderBlockEndColor = 245, BorderBlockStartColor = 246, BorderBottomColor = 247, BorderInlineEndColor = 248, BorderInlineStartColor = 249, BorderLeftColor = 250, BorderRightColor = 251, BorderTopColor = 252, OutlineColor = 253, TextDecorationColor = 254,
}
An identifier for a given longhand property.

Variants



AlignItems = 0

align-items



AlignmentBaseline = 1

alignment-baseline



BackfaceVisibility = 2

backface-visibility



BaselineSource = 3

baseline-source



BorderCollapse = 4

border-collapse



BorderImageRepeat = 5

border-image-repeat



BoxSizing = 6

box-sizing



CaptionSide = 7

caption-side



Clear = 8

clear



ColumnSpan = 9

column-span



Contain = 10

contain



ContainerType = 11

container-type



Direction = 12

direction



Display = 13

display



EmptyCells = 14

empty-cells



FlexDirection = 15

flex-direction



FlexWrap = 16

flex-wrap



Float = 17

float



FontKerning = 18

font-kerning



FontLanguageOverride = 19

font-language-override



FontOpticalSizing = 20

font-optical-sizing



FontSynthesisWeight = 21

font-synthesis-weight



FontVariantCaps = 22

font-variant-caps



FontVariantEastAsian = 23

font-variant-east-asian



FontVariantLigatures = 24

font-variant-ligatures



FontVariantNumeric = 25

font-variant-numeric



FontVariantPosition = 26

font-variant-position



GridAutoFlow = 27

grid-auto-flow



ImageRendering = 28

image-rendering



Isolation = 29

isolation



JustifyItems = 30

justify-items



LineBreak = 31

line-break



ListStylePosition = 32

list-style-position



MaskType = 33

mask-type



MixBlendMode = 34

mix-blend-mode



ObjectFit = 35

object-fit



OutlineStyle = 36

outline-style



OverflowWrap = 37

overflow-wrap



PointerEvents = 38

pointer-events



Position = 39

position



PositionArea = 40

position-area



ServoTopLayer = 41

-servo-top-layer



TableLayout = 42

table-layout



TextAlign = 43

text-align



TextAlignLast = 44

text-align-last



TextDecorationLine = 45

text-decoration-line



TextDecorationStyle = 46

text-decoration-style



TextJustify = 47

text-justify



TextRendering = 48

text-rendering



TextTransform = 49

text-transform



TextWrapMode = 50

text-wrap-mode



TransformStyle = 51

transform-style



UnicodeBidi = 52

unicode-bidi



UserSelect = 53

user-select



Visibility = 54

visibility



WebkitTextSecurity = 55

-webkit-text-security



WhiteSpaceCollapse = 56

white-space-collapse



WordBreak = 57

word-break



WritingMode = 58

writing-mode



AlignContent = 59

align-content



JustifyContent = 60

justify-content



AlignSelf = 61

align-self



JustifySelf = 62

justify-self



OverflowBlock = 63

overflow-block



OverflowInline = 64

overflow-inline



OverflowX = 65

overflow-x



OverflowY = 66

overflow-y



BorderBlockEndStyle = 67

border-block-end-style



BorderBlockStartStyle = 68

border-block-start-style



BorderBottomStyle = 69

border-bottom-style



BorderInlineEndStyle = 70

border-inline-end-style



BorderInlineStartStyle = 71

border-inline-start-style



BorderLeftStyle = 72

border-left-style



BorderRightStyle = 73

border-right-style



BorderTopStyle = 74

border-top-style



AnimationComposition = 75

animation-composition



AnimationDelay = 76

animation-delay



AnimationDirection = 77

animation-direction



AnimationDuration = 78

animation-duration



AnimationFillMode = 79

animation-fill-mode



AnimationIterationCount = 80

animation-iteration-count



AnimationName = 81

animation-name



AnimationPlayState = 82

animation-play-state



AnimationRangeEnd = 83

animation-range-end



AnimationRangeStart = 84

animation-range-start



AnimationTimeline = 85

animation-timeline



AnimationTimingFunction = 86

animation-timing-function



AspectRatio = 87

aspect-ratio



BackdropFilter = 88

backdrop-filter



BackgroundAttachment = 89

background-attachment



BackgroundBlendMode = 90

background-blend-mode



BackgroundClip = 91

background-clip



BackgroundImage = 92

background-image



BackgroundOrigin = 93

background-origin



BackgroundPositionX = 94

background-position-x



BackgroundPositionY = 95

background-position-y



BackgroundRepeat = 96

background-repeat



BackgroundSize = 97

background-size



BaselineShift = 98

baseline-shift



BorderImageOutset = 99

border-image-outset



BorderImageSlice = 100

border-image-slice



BorderImageWidth = 101

border-image-width



BorderSpacing = 102

border-spacing



BoxShadow = 103

box-shadow



CaretColor = 104

caret-color



Clip = 105

clip



ClipPath = 106

clip-path



Color = 107

color



ColorScheme = 108

color-scheme



ColumnCount = 109

column-count



ColumnWidth = 110

column-width



ContainerName = 111

container-name



Content = 112

content



CounterIncrement = 113

counter-increment



CounterReset = 114

counter-reset



Cursor = 115

cursor



Filter = 116

filter



FlexBasis = 117

flex-basis



FontFamily = 118

font-family



FontFeatureSettings = 119

font-feature-settings



FontSize = 120

font-size



FontStretch = 121

font-stretch



FontStyle = 122

font-style



FontVariationSettings = 123

font-variation-settings



FontWeight = 124

font-weight



GridTemplateAreas = 125

grid-template-areas



LetterSpacing = 126

letter-spacing



LineHeight = 127

line-height



ListStyleType = 128

list-style-type



MaskClip = 129

mask-clip



MaskComposite = 130

mask-composite



MaskImage = 131

mask-image



MaskMode = 132

mask-mode



MaskOrigin = 133

mask-origin



MaskPositionX = 134

mask-position-x



MaskPositionY = 135

mask-position-y



MaskRepeat = 136

mask-repeat



MaskSize = 137

mask-size



OffsetPath = 138

offset-path



Opacity = 139

opacity



Order = 140

order



OutlineOffset = 141

outline-offset



OverflowClipMargin = 142

overflow-clip-margin



Perspective = 143

perspective



PositionTryFallbacks = 144

position-try-fallbacks



Quotes = 145

quotes



Rotate = 146

rotate



Scale = 147

scale



TabSize = 148

tab-size



TextIndent = 149

text-indent



TextOverflow = 150

text-overflow



TextShadow = 151

text-shadow



Transform = 152

transform



TransformOrigin = 153

transform-origin



TransitionBehavior = 154

transition-behavior



TransitionDelay = 155

transition-delay



TransitionDuration = 156

transition-duration



TransitionProperty = 157

transition-property



TransitionTimingFunction = 158

transition-timing-function



Translate = 159

translate



ViewTransitionClass = 160

view-transition-class



ViewTransitionName = 161

view-transition-name



WillChange = 162

will-change



WordSpacing = 163

word-spacing



XLang = 164

-x-lang



ZIndex = 165

z-index



Zoom = 166

zoom



ObjectPosition = 167

object-position



PerspectiveOrigin = 168

perspective-origin



GridTemplateColumns = 169

grid-template-columns



GridTemplateRows = 170

grid-template-rows



BorderImageSource = 171

border-image-source



ListStyleImage = 172

list-style-image



GridAutoColumns = 173

grid-auto-columns



GridAutoRows = 174

grid-auto-rows



FlexGrow = 175

flex-grow



FlexShrink = 176

flex-shrink



ColumnGap = 177

column-gap



RowGap = 178

row-gap



GridColumnEnd = 179

grid-column-end



GridColumnStart = 180

grid-column-start



GridRowEnd = 181

grid-row-end



GridRowStart = 182

grid-row-start



MaxBlockSize = 183

max-block-size



MaxHeight = 184

max-height



MaxInlineSize = 185

max-inline-size



MaxWidth = 186

max-width



BorderBottomLeftRadius = 187

border-bottom-left-radius



BorderBottomRightRadius = 188

border-bottom-right-radius



BorderEndEndRadius = 189

border-end-end-radius



BorderEndStartRadius = 190

border-end-start-radius



BorderStartEndRadius = 191

border-start-end-radius



BorderStartStartRadius = 192

border-start-start-radius



BorderTopLeftRadius = 193

border-top-left-radius



BorderTopRightRadius = 194

border-top-right-radius



CornerBottomLeftShape = 195

corner-bottom-left-shape



CornerBottomRightShape = 196

corner-bottom-right-shape



CornerEndEndShape = 197

corner-end-end-shape



CornerEndStartShape = 198

corner-end-start-shape



CornerStartEndShape = 199

corner-start-end-shape



CornerStartStartShape = 200

corner-start-start-shape



CornerTopLeftShape = 201

corner-top-left-shape



CornerTopRightShape = 202

corner-top-right-shape



Bottom = 203

bottom



InsetBlockEnd = 204

inset-block-end



InsetBlockStart = 205

inset-block-start



InsetInlineEnd = 206

inset-inline-end



InsetInlineStart = 207

inset-inline-start



Left = 208

left



Right = 209

right



Top = 210

top



MarginBlockEnd = 211

margin-block-end



MarginBlockStart = 212

margin-block-start



MarginBottom = 213

margin-bottom



MarginInlineEnd = 214

margin-inline-end



MarginInlineStart = 215

margin-inline-start



MarginLeft = 216

margin-left



MarginRight = 217

margin-right



MarginTop = 218

margin-top



PaddingBlockEnd = 219

padding-block-end



PaddingBlockStart = 220

padding-block-start



PaddingBottom = 221

padding-bottom



PaddingInlineEnd = 222

padding-inline-end



PaddingInlineStart = 223

padding-inline-start



PaddingLeft = 224

padding-left



PaddingRight = 225

padding-right



PaddingTop = 226

padding-top



BlockSize = 227

block-size



Height = 228

height



InlineSize = 229

inline-size



MinBlockSize = 230

min-block-size



MinHeight = 231

min-height



MinInlineSize = 232

min-inline-size



MinWidth = 233

min-width



Width = 234

width



BorderBlockEndWidth = 235

border-block-end-width



BorderBlockStartWidth = 236

border-block-start-width



BorderBottomWidth = 237

border-bottom-width



BorderInlineEndWidth = 238

border-inline-end-width



BorderInlineStartWidth = 239

border-inline-start-width



BorderLeftWidth = 240

border-left-width



BorderRightWidth = 241

border-right-width



BorderTopWidth = 242

border-top-width



OutlineWidth = 243

outline-width



BackgroundColor = 244

background-color



BorderBlockEndColor = 245

border-block-end-color



BorderBlockStartColor = 246

border-block-start-color



BorderBottomColor = 247

border-bottom-color



BorderInlineEndColor = 248

border-inline-end-color



BorderInlineStartColor = 249

border-inline-start-color



BorderLeftColor = 250

border-left-color



BorderRightColor = 251

border-right-color



BorderTopColor = 252

border-top-color



OutlineColor = 253

outline-color



TextDecorationColor = 254

text-decoration-color

Implementations

Source

impl LonghandId

pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId>

Returns an iterator over all the shorthands that include this longhand.

pub(super) fn parse_value<'i, 't>( self, context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<PropertyDeclaration, ParseError<'i>>

fn logical_mapping_data(self) -> Option<&'static LogicalMappingData>

Return the relevant data to map a particular logical property into physical.

pub fn to_physical(self, wm: WritingMode) -> Self

If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.

pub fn logical_group(self) -> Option<LogicalGroupId>

Return the logical group of this longhand property.

pub fn flags(self) -> PropertyFlags

Returns PropertyFlags for given longhand property.

Source

impl LonghandId

pub fn name(&self) -> &'static str

Get the name of this longhand property.

pub fn inherited(self) -> bool

Returns whether the longhand property is inherited by default.

pub fn zoom_dependent(self) -> bool

Returns whether the longhand property is zoom-dependent.

pub fn ignored_when_document_colors_disabled(self) -> bool

Returns true if the property is one that is ignored when document colors are disabled.

pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool

Returns whether this longhand is non_custom or is a longhand of it.

pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool

Returns whether this longhand is a longhand of shorthand.

pub fn is_animatable(self) -> bool

Returns whether this property is animatable.

pub fn is_discrete_animatable(self) -> bool

Returns whether this property is animatable in a discrete way.

pub fn is_logical(self) -> bool

Return whether this property is logical.