#[repr(u16)]pub enum LonghandId {
Show 235 variants
AlignItems = 0,
AlignmentBaseline = 1,
AspectRatio = 2,
BackfaceVisibility = 3,
BaselineSource = 4,
BorderCollapse = 5,
BorderImageRepeat = 6,
BoxSizing = 7,
CaptionSide = 8,
Clear = 9,
ColumnCount = 10,
ColumnSpan = 11,
Contain = 12,
ContainerType = 13,
Direction = 14,
Display = 15,
EmptyCells = 16,
FlexDirection = 17,
FlexWrap = 18,
Float = 19,
FontKerning = 20,
FontLanguageOverride = 21,
FontOpticalSizing = 22,
FontStretch = 23,
FontStyle = 24,
FontSynthesisWeight = 25,
FontVariantCaps = 26,
FontVariantLigatures = 27,
FontVariantNumeric = 28,
FontWeight = 29,
GridAutoFlow = 30,
ImageRendering = 31,
Isolation = 32,
JustifyItems = 33,
LineBreak = 34,
ListStylePosition = 35,
MixBlendMode = 36,
ObjectFit = 37,
Opacity = 38,
Order = 39,
OutlineStyle = 40,
OverflowWrap = 41,
PointerEvents = 42,
Position = 43,
PositionArea = 44,
ServoTopLayer = 45,
TableLayout = 46,
TextAlign = 47,
TextAlignLast = 48,
TextDecorationLine = 49,
TextDecorationStyle = 50,
TextJustify = 51,
TextRendering = 52,
TextTransform = 53,
TextWrapMode = 54,
TransformStyle = 55,
UnicodeBidi = 56,
UserSelect = 57,
Visibility = 58,
WebkitTextSecurity = 59,
WhiteSpaceCollapse = 60,
WordBreak = 61,
WritingMode = 62,
ZIndex = 63,
Zoom = 64,
AlignContent = 65,
JustifyContent = 66,
FlexGrow = 67,
FlexShrink = 68,
AlignSelf = 69,
JustifySelf = 70,
OverflowBlock = 71,
OverflowInline = 72,
OverflowX = 73,
OverflowY = 74,
BorderBlockEndStyle = 75,
BorderBlockStartStyle = 76,
BorderBottomStyle = 77,
BorderInlineEndStyle = 78,
BorderInlineStartStyle = 79,
BorderLeftStyle = 80,
BorderRightStyle = 81,
BorderTopStyle = 82,
AnimationComposition = 83,
AnimationDelay = 84,
AnimationDirection = 85,
AnimationDuration = 86,
AnimationFillMode = 87,
AnimationIterationCount = 88,
AnimationName = 89,
AnimationPlayState = 90,
AnimationRangeEnd = 91,
AnimationRangeStart = 92,
AnimationTimeline = 93,
AnimationTimingFunction = 94,
BackdropFilter = 95,
BackgroundAttachment = 96,
BackgroundBlendMode = 97,
BackgroundClip = 98,
BackgroundImage = 99,
BackgroundOrigin = 100,
BackgroundPositionX = 101,
BackgroundPositionY = 102,
BackgroundRepeat = 103,
BackgroundSize = 104,
BaselineShift = 105,
BorderImageOutset = 106,
BorderImageSlice = 107,
BorderImageWidth = 108,
BorderSpacing = 109,
BoxShadow = 110,
CaretColor = 111,
Clip = 112,
ClipPath = 113,
Color = 114,
ColorScheme = 115,
ColumnWidth = 116,
ContainerName = 117,
Content = 118,
CounterIncrement = 119,
CounterReset = 120,
Cursor = 121,
Filter = 122,
FlexBasis = 123,
FontFamily = 124,
FontSize = 125,
FontVariationSettings = 126,
GridTemplateAreas = 127,
LetterSpacing = 128,
LineHeight = 129,
ListStyleType = 130,
MaskImage = 131,
OffsetPath = 132,
OutlineOffset = 133,
OverflowClipMargin = 134,
Perspective = 135,
PositionTryFallbacks = 136,
Quotes = 137,
Rotate = 138,
Scale = 139,
TabSize = 140,
TextIndent = 141,
TextOverflow = 142,
TextShadow = 143,
Transform = 144,
TransformOrigin = 145,
TransitionBehavior = 146,
TransitionDelay = 147,
TransitionDuration = 148,
TransitionProperty = 149,
TransitionTimingFunction = 150,
Translate = 151,
ViewTransitionClass = 152,
ViewTransitionName = 153,
WillChange = 154,
WordSpacing = 155,
XLang = 156,
ObjectPosition = 157,
PerspectiveOrigin = 158,
GridTemplateColumns = 159,
GridTemplateRows = 160,
BorderImageSource = 161,
ListStyleImage = 162,
GridAutoColumns = 163,
GridAutoRows = 164,
ColumnGap = 165,
RowGap = 166,
GridColumnEnd = 167,
GridColumnStart = 168,
GridRowEnd = 169,
GridRowStart = 170,
MaxBlockSize = 171,
MaxHeight = 172,
MaxInlineSize = 173,
MaxWidth = 174,
BorderBottomLeftRadius = 175,
BorderBottomRightRadius = 176,
BorderEndEndRadius = 177,
BorderEndStartRadius = 178,
BorderStartEndRadius = 179,
BorderStartStartRadius = 180,
BorderTopLeftRadius = 181,
BorderTopRightRadius = 182,
Bottom = 183,
InsetBlockEnd = 184,
InsetBlockStart = 185,
InsetInlineEnd = 186,
InsetInlineStart = 187,
Left = 188,
Right = 189,
Top = 190,
MarginBlockEnd = 191,
MarginBlockStart = 192,
MarginBottom = 193,
MarginInlineEnd = 194,
MarginInlineStart = 195,
MarginLeft = 196,
MarginRight = 197,
MarginTop = 198,
PaddingBlockEnd = 199,
PaddingBlockStart = 200,
PaddingBottom = 201,
PaddingInlineEnd = 202,
PaddingInlineStart = 203,
PaddingLeft = 204,
PaddingRight = 205,
PaddingTop = 206,
BlockSize = 207,
Height = 208,
InlineSize = 209,
MinBlockSize = 210,
MinHeight = 211,
MinInlineSize = 212,
MinWidth = 213,
Width = 214,
BorderBlockEndWidth = 215,
BorderBlockStartWidth = 216,
BorderBottomWidth = 217,
BorderInlineEndWidth = 218,
BorderInlineStartWidth = 219,
BorderLeftWidth = 220,
BorderRightWidth = 221,
BorderTopWidth = 222,
OutlineWidth = 223,
BackgroundColor = 224,
BorderBlockEndColor = 225,
BorderBlockStartColor = 226,
BorderBottomColor = 227,
BorderInlineEndColor = 228,
BorderInlineStartColor = 229,
BorderLeftColor = 230,
BorderRightColor = 231,
BorderTopColor = 232,
OutlineColor = 233,
TextDecorationColor = 234,
}Expand description
An identifier for a given longhand property.
Variants
AlignItems = 0
align-items
AlignmentBaseline = 1
alignment-baseline
AspectRatio = 2
aspect-ratio
BackfaceVisibility = 3
backface-visibility
BaselineSource = 4
baseline-source
BorderCollapse = 5
border-collapse
BorderImageRepeat = 6
border-image-repeat
BoxSizing = 7
box-sizing
CaptionSide = 8
caption-side
Clear = 9
clear
ColumnCount = 10
column-count
ColumnSpan = 11
column-span
Contain = 12
contain
ContainerType = 13
container-type
Direction = 14
direction
Display = 15
display
EmptyCells = 16
empty-cells
FlexDirection = 17
flex-direction
FlexWrap = 18
flex-wrap
Float = 19
float
FontKerning = 20
font-kerning
FontLanguageOverride = 21
font-language-override
FontOpticalSizing = 22
font-optical-sizing
FontStretch = 23
font-stretch
FontStyle = 24
font-style
FontSynthesisWeight = 25
font-synthesis-weight
FontVariantCaps = 26
font-variant-caps
FontVariantLigatures = 27
font-variant-ligatures
FontVariantNumeric = 28
font-variant-numeric
FontWeight = 29
font-weight
GridAutoFlow = 30
grid-auto-flow
ImageRendering = 31
image-rendering
Isolation = 32
isolation
JustifyItems = 33
justify-items
LineBreak = 34
line-break
ListStylePosition = 35
list-style-position
MixBlendMode = 36
mix-blend-mode
ObjectFit = 37
object-fit
Opacity = 38
opacity
Order = 39
order
OutlineStyle = 40
outline-style
OverflowWrap = 41
overflow-wrap
PointerEvents = 42
pointer-events
Position = 43
position
PositionArea = 44
position-area
ServoTopLayer = 45
-servo-top-layer
TableLayout = 46
table-layout
TextAlign = 47
text-align
TextAlignLast = 48
text-align-last
TextDecorationLine = 49
text-decoration-line
TextDecorationStyle = 50
text-decoration-style
TextJustify = 51
text-justify
TextRendering = 52
text-rendering
TextTransform = 53
text-transform
TextWrapMode = 54
text-wrap-mode
TransformStyle = 55
transform-style
UnicodeBidi = 56
unicode-bidi
UserSelect = 57
user-select
Visibility = 58
visibility
WebkitTextSecurity = 59
-webkit-text-security
WhiteSpaceCollapse = 60
white-space-collapse
WordBreak = 61
word-break
WritingMode = 62
writing-mode
ZIndex = 63
z-index
Zoom = 64
zoom
AlignContent = 65
align-content
JustifyContent = 66
justify-content
FlexGrow = 67
flex-grow
FlexShrink = 68
flex-shrink
AlignSelf = 69
align-self
JustifySelf = 70
justify-self
OverflowBlock = 71
overflow-block
OverflowInline = 72
overflow-inline
OverflowX = 73
overflow-x
OverflowY = 74
overflow-y
BorderBlockEndStyle = 75
border-block-end-style
BorderBlockStartStyle = 76
border-block-start-style
BorderBottomStyle = 77
border-bottom-style
BorderInlineEndStyle = 78
border-inline-end-style
BorderInlineStartStyle = 79
border-inline-start-style
BorderLeftStyle = 80
border-left-style
BorderRightStyle = 81
border-right-style
BorderTopStyle = 82
border-top-style
AnimationComposition = 83
animation-composition
AnimationDelay = 84
animation-delay
AnimationDirection = 85
animation-direction
AnimationDuration = 86
animation-duration
AnimationFillMode = 87
animation-fill-mode
AnimationIterationCount = 88
animation-iteration-count
AnimationName = 89
animation-name
AnimationPlayState = 90
animation-play-state
AnimationRangeEnd = 91
animation-range-end
AnimationRangeStart = 92
animation-range-start
AnimationTimeline = 93
animation-timeline
AnimationTimingFunction = 94
animation-timing-function
BackdropFilter = 95
backdrop-filter
BackgroundAttachment = 96
background-attachment
BackgroundBlendMode = 97
background-blend-mode
BackgroundClip = 98
background-clip
BackgroundImage = 99
background-image
BackgroundOrigin = 100
background-origin
BackgroundPositionX = 101
background-position-x
BackgroundPositionY = 102
background-position-y
BackgroundRepeat = 103
background-repeat
BackgroundSize = 104
background-size
BaselineShift = 105
baseline-shift
BorderImageOutset = 106
border-image-outset
BorderImageSlice = 107
border-image-slice
BorderImageWidth = 108
border-image-width
BorderSpacing = 109
border-spacing
BoxShadow = 110
box-shadow
CaretColor = 111
caret-color
Clip = 112
clip
ClipPath = 113
clip-path
Color = 114
color
ColorScheme = 115
color-scheme
ColumnWidth = 116
column-width
ContainerName = 117
container-name
Content = 118
content
CounterIncrement = 119
counter-increment
CounterReset = 120
counter-reset
Cursor = 121
cursor
Filter = 122
filter
FlexBasis = 123
flex-basis
FontFamily = 124
font-family
FontSize = 125
font-size
FontVariationSettings = 126
font-variation-settings
GridTemplateAreas = 127
grid-template-areas
LetterSpacing = 128
letter-spacing
LineHeight = 129
line-height
ListStyleType = 130
list-style-type
MaskImage = 131
mask-image
OffsetPath = 132
offset-path
OutlineOffset = 133
outline-offset
OverflowClipMargin = 134
overflow-clip-margin
Perspective = 135
perspective
PositionTryFallbacks = 136
position-try-fallbacks
Quotes = 137
quotes
Rotate = 138
rotate
Scale = 139
scale
TabSize = 140
tab-size
TextIndent = 141
text-indent
TextOverflow = 142
text-overflow
TextShadow = 143
text-shadow
Transform = 144
transform
TransformOrigin = 145
transform-origin
TransitionBehavior = 146
transition-behavior
TransitionDelay = 147
transition-delay
TransitionDuration = 148
transition-duration
TransitionProperty = 149
transition-property
TransitionTimingFunction = 150
transition-timing-function
Translate = 151
translate
ViewTransitionClass = 152
view-transition-class
ViewTransitionName = 153
view-transition-name
WillChange = 154
will-change
WordSpacing = 155
word-spacing
XLang = 156
-x-lang
ObjectPosition = 157
object-position
PerspectiveOrigin = 158
perspective-origin
GridTemplateColumns = 159
grid-template-columns
GridTemplateRows = 160
grid-template-rows
BorderImageSource = 161
border-image-source
ListStyleImage = 162
list-style-image
GridAutoColumns = 163
grid-auto-columns
GridAutoRows = 164
grid-auto-rows
ColumnGap = 165
column-gap
RowGap = 166
row-gap
GridColumnEnd = 167
grid-column-end
GridColumnStart = 168
grid-column-start
GridRowEnd = 169
grid-row-end
GridRowStart = 170
grid-row-start
MaxBlockSize = 171
max-block-size
MaxHeight = 172
max-height
MaxInlineSize = 173
max-inline-size
MaxWidth = 174
max-width
BorderBottomLeftRadius = 175
border-bottom-left-radius
BorderBottomRightRadius = 176
border-bottom-right-radius
BorderEndEndRadius = 177
border-end-end-radius
BorderEndStartRadius = 178
border-end-start-radius
BorderStartEndRadius = 179
border-start-end-radius
BorderStartStartRadius = 180
border-start-start-radius
BorderTopLeftRadius = 181
border-top-left-radius
BorderTopRightRadius = 182
border-top-right-radius
Bottom = 183
bottom
InsetBlockEnd = 184
inset-block-end
InsetBlockStart = 185
inset-block-start
InsetInlineEnd = 186
inset-inline-end
InsetInlineStart = 187
inset-inline-start
Left = 188
left
Right = 189
right
Top = 190
top
MarginBlockEnd = 191
margin-block-end
MarginBlockStart = 192
margin-block-start
MarginBottom = 193
margin-bottom
MarginInlineEnd = 194
margin-inline-end
MarginInlineStart = 195
margin-inline-start
MarginLeft = 196
margin-left
MarginRight = 197
margin-right
MarginTop = 198
margin-top
PaddingBlockEnd = 199
padding-block-end
PaddingBlockStart = 200
padding-block-start
PaddingBottom = 201
padding-bottom
PaddingInlineEnd = 202
padding-inline-end
PaddingInlineStart = 203
padding-inline-start
PaddingLeft = 204
padding-left
PaddingRight = 205
padding-right
PaddingTop = 206
padding-top
BlockSize = 207
block-size
Height = 208
height
InlineSize = 209
inline-size
MinBlockSize = 210
min-block-size
MinHeight = 211
min-height
MinInlineSize = 212
min-inline-size
MinWidth = 213
min-width
Width = 214
width
BorderBlockEndWidth = 215
border-block-end-width
BorderBlockStartWidth = 216
border-block-start-width
BorderBottomWidth = 217
border-bottom-width
BorderInlineEndWidth = 218
border-inline-end-width
BorderInlineStartWidth = 219
border-inline-start-width
BorderLeftWidth = 220
border-left-width
BorderRightWidth = 221
border-right-width
BorderTopWidth = 222
border-top-width
OutlineWidth = 223
outline-width
BackgroundColor = 224
background-color
BorderBlockEndColor = 225
border-block-end-color
BorderBlockStartColor = 226
border-block-start-color
BorderBottomColor = 227
border-bottom-color
BorderInlineEndColor = 228
border-inline-end-color
BorderInlineStartColor = 229
border-inline-start-color
BorderLeftColor = 230
border-left-color
BorderRightColor = 231
border-right-color
BorderTopColor = 232
border-top-color
OutlineColor = 233
outline-color
TextDecorationColor = 234
text-decoration-color
Implementations
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
Returns an iterator over all the shorthands that include this longhand.
pub(super) fn parse_value<'i, 't>( self, context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<PropertyDeclaration, ParseError<'i>>
Sourcefn logical_mapping_data(self) -> Option<&'static LogicalMappingData>
fn logical_mapping_data(self) -> Option<&'static LogicalMappingData>
Return the relevant data to map a particular logical property into physical.
Sourcepub fn to_physical(self, wm: WritingMode) -> Self
pub fn to_physical(self, wm: WritingMode) -> Self
If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.
Sourcepub fn logical_group(self) -> Option<LogicalGroupId>
pub fn logical_group(self) -> Option<LogicalGroupId>
Return the logical group of this longhand property.
Sourcepub fn flags(self) -> PropertyFlags
pub fn flags(self) -> PropertyFlags
Returns PropertyFlags for given longhand property.
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn zoom_dependent(self) -> bool
pub fn zoom_dependent(self) -> bool
Returns whether the longhand property is zoom-dependent.
Sourcepub fn ignored_when_document_colors_disabled(self) -> bool
pub fn ignored_when_document_colors_disabled(self) -> bool
Returns true if the property is one that is ignored when document colors are disabled.
Sourcepub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
Returns whether this longhand is non_custom or is a longhand of it.
Sourcepub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
Returns whether this longhand is a longhand of shorthand.
Sourcepub fn is_animatable(self) -> bool
pub fn is_animatable(self) -> bool
Returns whether this property is animatable.
Sourcepub fn is_discrete_animatable(self) -> bool
pub fn is_discrete_animatable(self) -> bool
Returns whether this property is animatable in a discrete way.
Sourcepub fn is_logical(self) -> bool
pub fn is_logical(self) -> bool
Return whether this property is logical.