#[repr(u16)]pub enum LonghandId {
Show 231 variants
AlignItems = 0,
AlignmentBaseline = 1,
AspectRatio = 2,
BackfaceVisibility = 3,
BaselineSource = 4,
BorderCollapse = 5,
BorderImageRepeat = 6,
BoxSizing = 7,
CaptionSide = 8,
Clear = 9,
ColumnCount = 10,
ColumnSpan = 11,
Contain = 12,
ContainerType = 13,
Direction = 14,
Display = 15,
EmptyCells = 16,
FlexDirection = 17,
FlexWrap = 18,
Float = 19,
FontLanguageOverride = 20,
FontOpticalSizing = 21,
FontStretch = 22,
FontStyle = 23,
FontSynthesisWeight = 24,
FontVariantCaps = 25,
FontWeight = 26,
GridAutoFlow = 27,
ImageRendering = 28,
Isolation = 29,
JustifyItems = 30,
LineBreak = 31,
ListStylePosition = 32,
MixBlendMode = 33,
ObjectFit = 34,
Opacity = 35,
Order = 36,
OutlineStyle = 37,
OverflowWrap = 38,
PointerEvents = 39,
Position = 40,
PositionArea = 41,
ServoOverflowClipBox = 42,
ServoTopLayer = 43,
TableLayout = 44,
TextAlign = 45,
TextAlignLast = 46,
TextDecorationLine = 47,
TextDecorationStyle = 48,
TextJustify = 49,
TextRendering = 50,
TextTransform = 51,
TextWrapMode = 52,
TransformStyle = 53,
UnicodeBidi = 54,
Visibility = 55,
WebkitTextSecurity = 56,
WhiteSpaceCollapse = 57,
WordBreak = 58,
WritingMode = 59,
ZIndex = 60,
Zoom = 61,
AlignContent = 62,
JustifyContent = 63,
FlexGrow = 64,
FlexShrink = 65,
AlignSelf = 66,
JustifySelf = 67,
OverflowBlock = 68,
OverflowInline = 69,
OverflowX = 70,
OverflowY = 71,
BorderBlockEndStyle = 72,
BorderBlockStartStyle = 73,
BorderBottomStyle = 74,
BorderInlineEndStyle = 75,
BorderInlineStartStyle = 76,
BorderLeftStyle = 77,
BorderRightStyle = 78,
BorderTopStyle = 79,
AnimationComposition = 80,
AnimationDelay = 81,
AnimationDirection = 82,
AnimationDuration = 83,
AnimationFillMode = 84,
AnimationIterationCount = 85,
AnimationName = 86,
AnimationPlayState = 87,
AnimationRangeEnd = 88,
AnimationRangeStart = 89,
AnimationTimeline = 90,
AnimationTimingFunction = 91,
BackdropFilter = 92,
BackgroundAttachment = 93,
BackgroundBlendMode = 94,
BackgroundClip = 95,
BackgroundImage = 96,
BackgroundOrigin = 97,
BackgroundPositionX = 98,
BackgroundPositionY = 99,
BackgroundRepeat = 100,
BackgroundSize = 101,
BaselineShift = 102,
BorderImageOutset = 103,
BorderImageSlice = 104,
BorderImageWidth = 105,
BorderSpacing = 106,
BoxShadow = 107,
CaretColor = 108,
Clip = 109,
ClipPath = 110,
Color = 111,
ColorScheme = 112,
ColumnWidth = 113,
ContainerName = 114,
Content = 115,
CounterIncrement = 116,
CounterReset = 117,
Cursor = 118,
Filter = 119,
FlexBasis = 120,
FontFamily = 121,
FontSize = 122,
FontVariationSettings = 123,
GridTemplateAreas = 124,
LetterSpacing = 125,
LineHeight = 126,
ListStyleType = 127,
MaskImage = 128,
OffsetPath = 129,
OutlineOffset = 130,
OverflowClipMargin = 131,
Perspective = 132,
PositionTryFallbacks = 133,
Quotes = 134,
Rotate = 135,
Scale = 136,
TextIndent = 137,
TextOverflow = 138,
TextShadow = 139,
Transform = 140,
TransformOrigin = 141,
TransitionBehavior = 142,
TransitionDelay = 143,
TransitionDuration = 144,
TransitionProperty = 145,
TransitionTimingFunction = 146,
Translate = 147,
ViewTransitionClass = 148,
ViewTransitionName = 149,
WillChange = 150,
WordSpacing = 151,
XLang = 152,
ObjectPosition = 153,
PerspectiveOrigin = 154,
GridTemplateColumns = 155,
GridTemplateRows = 156,
BorderImageSource = 157,
ListStyleImage = 158,
GridAutoColumns = 159,
GridAutoRows = 160,
ColumnGap = 161,
RowGap = 162,
GridColumnEnd = 163,
GridColumnStart = 164,
GridRowEnd = 165,
GridRowStart = 166,
MaxBlockSize = 167,
MaxHeight = 168,
MaxInlineSize = 169,
MaxWidth = 170,
BorderBottomLeftRadius = 171,
BorderBottomRightRadius = 172,
BorderEndEndRadius = 173,
BorderEndStartRadius = 174,
BorderStartEndRadius = 175,
BorderStartStartRadius = 176,
BorderTopLeftRadius = 177,
BorderTopRightRadius = 178,
Bottom = 179,
InsetBlockEnd = 180,
InsetBlockStart = 181,
InsetInlineEnd = 182,
InsetInlineStart = 183,
Left = 184,
Right = 185,
Top = 186,
MarginBlockEnd = 187,
MarginBlockStart = 188,
MarginBottom = 189,
MarginInlineEnd = 190,
MarginInlineStart = 191,
MarginLeft = 192,
MarginRight = 193,
MarginTop = 194,
PaddingBlockEnd = 195,
PaddingBlockStart = 196,
PaddingBottom = 197,
PaddingInlineEnd = 198,
PaddingInlineStart = 199,
PaddingLeft = 200,
PaddingRight = 201,
PaddingTop = 202,
BlockSize = 203,
Height = 204,
InlineSize = 205,
MinBlockSize = 206,
MinHeight = 207,
MinInlineSize = 208,
MinWidth = 209,
Width = 210,
BorderBlockEndWidth = 211,
BorderBlockStartWidth = 212,
BorderBottomWidth = 213,
BorderInlineEndWidth = 214,
BorderInlineStartWidth = 215,
BorderLeftWidth = 216,
BorderRightWidth = 217,
BorderTopWidth = 218,
OutlineWidth = 219,
BackgroundColor = 220,
BorderBlockEndColor = 221,
BorderBlockStartColor = 222,
BorderBottomColor = 223,
BorderInlineEndColor = 224,
BorderInlineStartColor = 225,
BorderLeftColor = 226,
BorderRightColor = 227,
BorderTopColor = 228,
OutlineColor = 229,
TextDecorationColor = 230,
}Expand description
An identifier for a given longhand property.
Variants
AlignItems = 0
align-items
AlignmentBaseline = 1
alignment-baseline
AspectRatio = 2
aspect-ratio
BackfaceVisibility = 3
backface-visibility
BaselineSource = 4
baseline-source
BorderCollapse = 5
border-collapse
BorderImageRepeat = 6
border-image-repeat
BoxSizing = 7
box-sizing
CaptionSide = 8
caption-side
Clear = 9
clear
ColumnCount = 10
column-count
ColumnSpan = 11
column-span
Contain = 12
contain
ContainerType = 13
container-type
Direction = 14
direction
Display = 15
display
EmptyCells = 16
empty-cells
FlexDirection = 17
flex-direction
FlexWrap = 18
flex-wrap
Float = 19
float
FontLanguageOverride = 20
font-language-override
FontOpticalSizing = 21
font-optical-sizing
FontStretch = 22
font-stretch
FontStyle = 23
font-style
FontSynthesisWeight = 24
font-synthesis-weight
FontVariantCaps = 25
font-variant-caps
FontWeight = 26
font-weight
GridAutoFlow = 27
grid-auto-flow
ImageRendering = 28
image-rendering
Isolation = 29
isolation
JustifyItems = 30
justify-items
LineBreak = 31
line-break
ListStylePosition = 32
list-style-position
MixBlendMode = 33
mix-blend-mode
ObjectFit = 34
object-fit
Opacity = 35
opacity
Order = 36
order
OutlineStyle = 37
outline-style
OverflowWrap = 38
overflow-wrap
PointerEvents = 39
pointer-events
Position = 40
position
PositionArea = 41
position-area
ServoOverflowClipBox = 42
-servo-overflow-clip-box
ServoTopLayer = 43
-servo-top-layer
TableLayout = 44
table-layout
TextAlign = 45
text-align
TextAlignLast = 46
text-align-last
TextDecorationLine = 47
text-decoration-line
TextDecorationStyle = 48
text-decoration-style
TextJustify = 49
text-justify
TextRendering = 50
text-rendering
TextTransform = 51
text-transform
TextWrapMode = 52
text-wrap-mode
TransformStyle = 53
transform-style
UnicodeBidi = 54
unicode-bidi
Visibility = 55
visibility
WebkitTextSecurity = 56
-webkit-text-security
WhiteSpaceCollapse = 57
white-space-collapse
WordBreak = 58
word-break
WritingMode = 59
writing-mode
ZIndex = 60
z-index
Zoom = 61
zoom
AlignContent = 62
align-content
JustifyContent = 63
justify-content
FlexGrow = 64
flex-grow
FlexShrink = 65
flex-shrink
AlignSelf = 66
align-self
JustifySelf = 67
justify-self
OverflowBlock = 68
overflow-block
OverflowInline = 69
overflow-inline
OverflowX = 70
overflow-x
OverflowY = 71
overflow-y
BorderBlockEndStyle = 72
border-block-end-style
BorderBlockStartStyle = 73
border-block-start-style
BorderBottomStyle = 74
border-bottom-style
BorderInlineEndStyle = 75
border-inline-end-style
BorderInlineStartStyle = 76
border-inline-start-style
BorderLeftStyle = 77
border-left-style
BorderRightStyle = 78
border-right-style
BorderTopStyle = 79
border-top-style
AnimationComposition = 80
animation-composition
AnimationDelay = 81
animation-delay
AnimationDirection = 82
animation-direction
AnimationDuration = 83
animation-duration
AnimationFillMode = 84
animation-fill-mode
AnimationIterationCount = 85
animation-iteration-count
AnimationName = 86
animation-name
AnimationPlayState = 87
animation-play-state
AnimationRangeEnd = 88
animation-range-end
AnimationRangeStart = 89
animation-range-start
AnimationTimeline = 90
animation-timeline
AnimationTimingFunction = 91
animation-timing-function
BackdropFilter = 92
backdrop-filter
BackgroundAttachment = 93
background-attachment
BackgroundBlendMode = 94
background-blend-mode
BackgroundClip = 95
background-clip
BackgroundImage = 96
background-image
BackgroundOrigin = 97
background-origin
BackgroundPositionX = 98
background-position-x
BackgroundPositionY = 99
background-position-y
BackgroundRepeat = 100
background-repeat
BackgroundSize = 101
background-size
BaselineShift = 102
baseline-shift
BorderImageOutset = 103
border-image-outset
BorderImageSlice = 104
border-image-slice
BorderImageWidth = 105
border-image-width
BorderSpacing = 106
border-spacing
BoxShadow = 107
box-shadow
CaretColor = 108
caret-color
Clip = 109
clip
ClipPath = 110
clip-path
Color = 111
color
ColorScheme = 112
color-scheme
ColumnWidth = 113
column-width
ContainerName = 114
container-name
Content = 115
content
CounterIncrement = 116
counter-increment
CounterReset = 117
counter-reset
Cursor = 118
cursor
Filter = 119
filter
FlexBasis = 120
flex-basis
FontFamily = 121
font-family
FontSize = 122
font-size
FontVariationSettings = 123
font-variation-settings
GridTemplateAreas = 124
grid-template-areas
LetterSpacing = 125
letter-spacing
LineHeight = 126
line-height
ListStyleType = 127
list-style-type
MaskImage = 128
mask-image
OffsetPath = 129
offset-path
OutlineOffset = 130
outline-offset
OverflowClipMargin = 131
overflow-clip-margin
Perspective = 132
perspective
PositionTryFallbacks = 133
position-try-fallbacks
Quotes = 134
quotes
Rotate = 135
rotate
Scale = 136
scale
TextIndent = 137
text-indent
TextOverflow = 138
text-overflow
TextShadow = 139
text-shadow
Transform = 140
transform
TransformOrigin = 141
transform-origin
TransitionBehavior = 142
transition-behavior
TransitionDelay = 143
transition-delay
TransitionDuration = 144
transition-duration
TransitionProperty = 145
transition-property
TransitionTimingFunction = 146
transition-timing-function
Translate = 147
translate
ViewTransitionClass = 148
view-transition-class
ViewTransitionName = 149
view-transition-name
WillChange = 150
will-change
WordSpacing = 151
word-spacing
XLang = 152
-x-lang
ObjectPosition = 153
object-position
PerspectiveOrigin = 154
perspective-origin
GridTemplateColumns = 155
grid-template-columns
GridTemplateRows = 156
grid-template-rows
BorderImageSource = 157
border-image-source
ListStyleImage = 158
list-style-image
GridAutoColumns = 159
grid-auto-columns
GridAutoRows = 160
grid-auto-rows
ColumnGap = 161
column-gap
RowGap = 162
row-gap
GridColumnEnd = 163
grid-column-end
GridColumnStart = 164
grid-column-start
GridRowEnd = 165
grid-row-end
GridRowStart = 166
grid-row-start
MaxBlockSize = 167
max-block-size
MaxHeight = 168
max-height
MaxInlineSize = 169
max-inline-size
MaxWidth = 170
max-width
BorderBottomLeftRadius = 171
border-bottom-left-radius
BorderBottomRightRadius = 172
border-bottom-right-radius
BorderEndEndRadius = 173
border-end-end-radius
BorderEndStartRadius = 174
border-end-start-radius
BorderStartEndRadius = 175
border-start-end-radius
BorderStartStartRadius = 176
border-start-start-radius
BorderTopLeftRadius = 177
border-top-left-radius
BorderTopRightRadius = 178
border-top-right-radius
Bottom = 179
bottom
InsetBlockEnd = 180
inset-block-end
InsetBlockStart = 181
inset-block-start
InsetInlineEnd = 182
inset-inline-end
InsetInlineStart = 183
inset-inline-start
Left = 184
left
Right = 185
right
Top = 186
top
MarginBlockEnd = 187
margin-block-end
MarginBlockStart = 188
margin-block-start
MarginBottom = 189
margin-bottom
MarginInlineEnd = 190
margin-inline-end
MarginInlineStart = 191
margin-inline-start
MarginLeft = 192
margin-left
MarginRight = 193
margin-right
MarginTop = 194
margin-top
PaddingBlockEnd = 195
padding-block-end
PaddingBlockStart = 196
padding-block-start
PaddingBottom = 197
padding-bottom
PaddingInlineEnd = 198
padding-inline-end
PaddingInlineStart = 199
padding-inline-start
PaddingLeft = 200
padding-left
PaddingRight = 201
padding-right
PaddingTop = 202
padding-top
BlockSize = 203
block-size
Height = 204
height
InlineSize = 205
inline-size
MinBlockSize = 206
min-block-size
MinHeight = 207
min-height
MinInlineSize = 208
min-inline-size
MinWidth = 209
min-width
Width = 210
width
BorderBlockEndWidth = 211
border-block-end-width
BorderBlockStartWidth = 212
border-block-start-width
BorderBottomWidth = 213
border-bottom-width
BorderInlineEndWidth = 214
border-inline-end-width
BorderInlineStartWidth = 215
border-inline-start-width
BorderLeftWidth = 216
border-left-width
BorderRightWidth = 217
border-right-width
BorderTopWidth = 218
border-top-width
OutlineWidth = 219
outline-width
BackgroundColor = 220
background-color
BorderBlockEndColor = 221
border-block-end-color
BorderBlockStartColor = 222
border-block-start-color
BorderBottomColor = 223
border-bottom-color
BorderInlineEndColor = 224
border-inline-end-color
BorderInlineStartColor = 225
border-inline-start-color
BorderLeftColor = 226
border-left-color
BorderRightColor = 227
border-right-color
BorderTopColor = 228
border-top-color
OutlineColor = 229
outline-color
TextDecorationColor = 230
text-decoration-color
Implementations
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
Returns an iterator over all the shorthands that include this longhand.
pub(super) fn parse_value<'i, 't>( self, context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<PropertyDeclaration, ParseError<'i>>
Sourcefn logical_mapping_data(self) -> Option<&'static LogicalMappingData>
fn logical_mapping_data(self) -> Option<&'static LogicalMappingData>
Return the relevant data to map a particular logical property into physical.
Sourcepub fn to_physical(self, wm: WritingMode) -> Self
pub fn to_physical(self, wm: WritingMode) -> Self
If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.
Sourcepub fn logical_group(self) -> Option<LogicalGroupId>
pub fn logical_group(self) -> Option<LogicalGroupId>
Return the logical group of this longhand property.
Sourcepub fn flags(self) -> PropertyFlags
pub fn flags(self) -> PropertyFlags
Returns PropertyFlags for given longhand property.
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn zoom_dependent(self) -> bool
pub fn zoom_dependent(self) -> bool
Returns whether the longhand property is zoom-dependent.
Sourcepub fn ignored_when_document_colors_disabled(self) -> bool
pub fn ignored_when_document_colors_disabled(self) -> bool
Returns true if the property is one that is ignored when document colors are disabled.
Sourcepub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
Returns whether this longhand is non_custom or is a longhand of it.
Sourcepub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
Returns whether this longhand is a longhand of shorthand.
Sourcepub fn is_animatable(self) -> bool
pub fn is_animatable(self) -> bool
Returns whether this property is animatable.
Sourcepub fn is_discrete_animatable(self) -> bool
pub fn is_discrete_animatable(self) -> bool
Returns whether this property is animatable in a discrete way.
Sourcepub fn is_logical(self) -> bool
pub fn is_logical(self) -> bool
Return whether this property is logical.