LonghandId

Enum LonghandId 

#[repr(u16)]
pub enum LonghandId {
Show 230 variants AlignItems = 0, AlignmentBaseline = 1, AspectRatio = 2, BackfaceVisibility = 3, BaselineSource = 4, BorderCollapse = 5, BorderImageRepeat = 6, BoxSizing = 7, CaptionSide = 8, Clear = 9, ColumnCount = 10, ColumnSpan = 11, Contain = 12, ContainerType = 13, Direction = 14, Display = 15, EmptyCells = 16, FlexDirection = 17, FlexWrap = 18, Float = 19, FontLanguageOverride = 20, FontOpticalSizing = 21, FontStretch = 22, FontStyle = 23, FontSynthesisWeight = 24, FontVariantCaps = 25, FontWeight = 26, GridAutoFlow = 27, ImageRendering = 28, Isolation = 29, JustifyItems = 30, LineBreak = 31, ListStylePosition = 32, MixBlendMode = 33, ObjectFit = 34, Opacity = 35, Order = 36, OutlineStyle = 37, OverflowWrap = 38, PointerEvents = 39, Position = 40, PositionArea = 41, ServoOverflowClipBox = 42, ServoTopLayer = 43, TableLayout = 44, TextAlign = 45, TextAlignLast = 46, TextDecorationLine = 47, TextDecorationStyle = 48, TextJustify = 49, TextRendering = 50, TextTransform = 51, TextWrapMode = 52, TransformStyle = 53, UnicodeBidi = 54, Visibility = 55, WebkitTextSecurity = 56, WhiteSpaceCollapse = 57, WordBreak = 58, WritingMode = 59, ZIndex = 60, Zoom = 61, AlignContent = 62, JustifyContent = 63, FlexGrow = 64, FlexShrink = 65, AlignSelf = 66, JustifySelf = 67, OverflowBlock = 68, OverflowInline = 69, OverflowX = 70, OverflowY = 71, BorderBlockEndStyle = 72, BorderBlockStartStyle = 73, BorderBottomStyle = 74, BorderInlineEndStyle = 75, BorderInlineStartStyle = 76, BorderLeftStyle = 77, BorderRightStyle = 78, BorderTopStyle = 79, AnimationComposition = 80, AnimationDelay = 81, AnimationDirection = 82, AnimationDuration = 83, AnimationFillMode = 84, AnimationIterationCount = 85, AnimationName = 86, AnimationPlayState = 87, AnimationRangeEnd = 88, AnimationRangeStart = 89, AnimationTimeline = 90, AnimationTimingFunction = 91, BackdropFilter = 92, BackgroundAttachment = 93, BackgroundClip = 94, BackgroundImage = 95, BackgroundOrigin = 96, BackgroundPositionX = 97, BackgroundPositionY = 98, BackgroundRepeat = 99, BackgroundSize = 100, BaselineShift = 101, BorderImageOutset = 102, BorderImageSlice = 103, BorderImageWidth = 104, BorderSpacing = 105, BoxShadow = 106, CaretColor = 107, Clip = 108, ClipPath = 109, Color = 110, ColorScheme = 111, ColumnWidth = 112, ContainerName = 113, Content = 114, CounterIncrement = 115, CounterReset = 116, Cursor = 117, Filter = 118, FlexBasis = 119, FontFamily = 120, FontSize = 121, FontVariationSettings = 122, GridTemplateAreas = 123, LetterSpacing = 124, LineHeight = 125, ListStyleType = 126, MaskImage = 127, OffsetPath = 128, OutlineOffset = 129, OverflowClipMargin = 130, Perspective = 131, PositionTryFallbacks = 132, Quotes = 133, Rotate = 134, Scale = 135, TextIndent = 136, TextOverflow = 137, TextShadow = 138, Transform = 139, TransformOrigin = 140, TransitionBehavior = 141, TransitionDelay = 142, TransitionDuration = 143, TransitionProperty = 144, TransitionTimingFunction = 145, Translate = 146, ViewTransitionClass = 147, ViewTransitionName = 148, WillChange = 149, WordSpacing = 150, XLang = 151, ObjectPosition = 152, PerspectiveOrigin = 153, GridTemplateColumns = 154, GridTemplateRows = 155, BorderImageSource = 156, ListStyleImage = 157, GridAutoColumns = 158, GridAutoRows = 159, ColumnGap = 160, RowGap = 161, GridColumnEnd = 162, GridColumnStart = 163, GridRowEnd = 164, GridRowStart = 165, MaxBlockSize = 166, MaxHeight = 167, MaxInlineSize = 168, MaxWidth = 169, BorderBottomLeftRadius = 170, BorderBottomRightRadius = 171, BorderEndEndRadius = 172, BorderEndStartRadius = 173, BorderStartEndRadius = 174, BorderStartStartRadius = 175, BorderTopLeftRadius = 176, BorderTopRightRadius = 177, Bottom = 178, InsetBlockEnd = 179, InsetBlockStart = 180, InsetInlineEnd = 181, InsetInlineStart = 182, Left = 183, Right = 184, Top = 185, MarginBlockEnd = 186, MarginBlockStart = 187, MarginBottom = 188, MarginInlineEnd = 189, MarginInlineStart = 190, MarginLeft = 191, MarginRight = 192, MarginTop = 193, PaddingBlockEnd = 194, PaddingBlockStart = 195, PaddingBottom = 196, PaddingInlineEnd = 197, PaddingInlineStart = 198, PaddingLeft = 199, PaddingRight = 200, PaddingTop = 201, BlockSize = 202, Height = 203, InlineSize = 204, MinBlockSize = 205, MinHeight = 206, MinInlineSize = 207, MinWidth = 208, Width = 209, BorderBlockEndWidth = 210, BorderBlockStartWidth = 211, BorderBottomWidth = 212, BorderInlineEndWidth = 213, BorderInlineStartWidth = 214, BorderLeftWidth = 215, BorderRightWidth = 216, BorderTopWidth = 217, OutlineWidth = 218, BackgroundColor = 219, BorderBlockEndColor = 220, BorderBlockStartColor = 221, BorderBottomColor = 222, BorderInlineEndColor = 223, BorderInlineStartColor = 224, BorderLeftColor = 225, BorderRightColor = 226, BorderTopColor = 227, OutlineColor = 228, TextDecorationColor = 229,
}
An identifier for a given longhand property.

Variants



AlignItems = 0

align-items



AlignmentBaseline = 1

alignment-baseline



AspectRatio = 2

aspect-ratio



BackfaceVisibility = 3

backface-visibility



BaselineSource = 4

baseline-source



BorderCollapse = 5

border-collapse



BorderImageRepeat = 6

border-image-repeat



BoxSizing = 7

box-sizing



CaptionSide = 8

caption-side



Clear = 9

clear



ColumnCount = 10

column-count



ColumnSpan = 11

column-span



Contain = 12

contain



ContainerType = 13

container-type



Direction = 14

direction



Display = 15

display



EmptyCells = 16

empty-cells



FlexDirection = 17

flex-direction



FlexWrap = 18

flex-wrap



Float = 19

float



FontLanguageOverride = 20

font-language-override



FontOpticalSizing = 21

font-optical-sizing



FontStretch = 22

font-stretch



FontStyle = 23

font-style



FontSynthesisWeight = 24

font-synthesis-weight



FontVariantCaps = 25

font-variant-caps



FontWeight = 26

font-weight



GridAutoFlow = 27

grid-auto-flow



ImageRendering = 28

image-rendering



Isolation = 29

isolation



JustifyItems = 30

justify-items



LineBreak = 31

line-break



ListStylePosition = 32

list-style-position



MixBlendMode = 33

mix-blend-mode



ObjectFit = 34

object-fit



Opacity = 35

opacity



Order = 36

order



OutlineStyle = 37

outline-style



OverflowWrap = 38

overflow-wrap



PointerEvents = 39

pointer-events



Position = 40

position



PositionArea = 41

position-area



ServoOverflowClipBox = 42

-servo-overflow-clip-box



ServoTopLayer = 43

-servo-top-layer



TableLayout = 44

table-layout



TextAlign = 45

text-align



TextAlignLast = 46

text-align-last



TextDecorationLine = 47

text-decoration-line



TextDecorationStyle = 48

text-decoration-style



TextJustify = 49

text-justify



TextRendering = 50

text-rendering



TextTransform = 51

text-transform



TextWrapMode = 52

text-wrap-mode



TransformStyle = 53

transform-style



UnicodeBidi = 54

unicode-bidi



Visibility = 55

visibility



WebkitTextSecurity = 56

-webkit-text-security



WhiteSpaceCollapse = 57

white-space-collapse



WordBreak = 58

word-break



WritingMode = 59

writing-mode



ZIndex = 60

z-index



Zoom = 61

zoom



AlignContent = 62

align-content



JustifyContent = 63

justify-content



FlexGrow = 64

flex-grow



FlexShrink = 65

flex-shrink



AlignSelf = 66

align-self



JustifySelf = 67

justify-self



OverflowBlock = 68

overflow-block



OverflowInline = 69

overflow-inline



OverflowX = 70

overflow-x



OverflowY = 71

overflow-y



BorderBlockEndStyle = 72

border-block-end-style



BorderBlockStartStyle = 73

border-block-start-style



BorderBottomStyle = 74

border-bottom-style



BorderInlineEndStyle = 75

border-inline-end-style



BorderInlineStartStyle = 76

border-inline-start-style



BorderLeftStyle = 77

border-left-style



BorderRightStyle = 78

border-right-style



BorderTopStyle = 79

border-top-style



AnimationComposition = 80

animation-composition



AnimationDelay = 81

animation-delay



AnimationDirection = 82

animation-direction



AnimationDuration = 83

animation-duration



AnimationFillMode = 84

animation-fill-mode



AnimationIterationCount = 85

animation-iteration-count



AnimationName = 86

animation-name



AnimationPlayState = 87

animation-play-state



AnimationRangeEnd = 88

animation-range-end



AnimationRangeStart = 89

animation-range-start



AnimationTimeline = 90

animation-timeline



AnimationTimingFunction = 91

animation-timing-function



BackdropFilter = 92

backdrop-filter



BackgroundAttachment = 93

background-attachment



BackgroundClip = 94

background-clip



BackgroundImage = 95

background-image



BackgroundOrigin = 96

background-origin



BackgroundPositionX = 97

background-position-x



BackgroundPositionY = 98

background-position-y



BackgroundRepeat = 99

background-repeat



BackgroundSize = 100

background-size



BaselineShift = 101

baseline-shift



BorderImageOutset = 102

border-image-outset



BorderImageSlice = 103

border-image-slice



BorderImageWidth = 104

border-image-width



BorderSpacing = 105

border-spacing



BoxShadow = 106

box-shadow



CaretColor = 107

caret-color



Clip = 108

clip



ClipPath = 109

clip-path



Color = 110

color



ColorScheme = 111

color-scheme



ColumnWidth = 112

column-width



ContainerName = 113

container-name



Content = 114

content



CounterIncrement = 115

counter-increment



CounterReset = 116

counter-reset



Cursor = 117

cursor



Filter = 118

filter



FlexBasis = 119

flex-basis



FontFamily = 120

font-family



FontSize = 121

font-size



FontVariationSettings = 122

font-variation-settings



GridTemplateAreas = 123

grid-template-areas



LetterSpacing = 124

letter-spacing



LineHeight = 125

line-height



ListStyleType = 126

list-style-type



MaskImage = 127

mask-image



OffsetPath = 128

offset-path



OutlineOffset = 129

outline-offset



OverflowClipMargin = 130

overflow-clip-margin



Perspective = 131

perspective



PositionTryFallbacks = 132

position-try-fallbacks



Quotes = 133

quotes



Rotate = 134

rotate



Scale = 135

scale



TextIndent = 136

text-indent



TextOverflow = 137

text-overflow



TextShadow = 138

text-shadow



Transform = 139

transform



TransformOrigin = 140

transform-origin



TransitionBehavior = 141

transition-behavior



TransitionDelay = 142

transition-delay



TransitionDuration = 143

transition-duration



TransitionProperty = 144

transition-property



TransitionTimingFunction = 145

transition-timing-function



Translate = 146

translate



ViewTransitionClass = 147

view-transition-class



ViewTransitionName = 148

view-transition-name



WillChange = 149

will-change



WordSpacing = 150

word-spacing



XLang = 151

-x-lang



ObjectPosition = 152

object-position



PerspectiveOrigin = 153

perspective-origin



GridTemplateColumns = 154

grid-template-columns



GridTemplateRows = 155

grid-template-rows



BorderImageSource = 156

border-image-source



ListStyleImage = 157

list-style-image



GridAutoColumns = 158

grid-auto-columns



GridAutoRows = 159

grid-auto-rows



ColumnGap = 160

column-gap



RowGap = 161

row-gap



GridColumnEnd = 162

grid-column-end



GridColumnStart = 163

grid-column-start



GridRowEnd = 164

grid-row-end



GridRowStart = 165

grid-row-start



MaxBlockSize = 166

max-block-size



MaxHeight = 167

max-height



MaxInlineSize = 168

max-inline-size



MaxWidth = 169

max-width



BorderBottomLeftRadius = 170

border-bottom-left-radius



BorderBottomRightRadius = 171

border-bottom-right-radius



BorderEndEndRadius = 172

border-end-end-radius



BorderEndStartRadius = 173

border-end-start-radius



BorderStartEndRadius = 174

border-start-end-radius



BorderStartStartRadius = 175

border-start-start-radius



BorderTopLeftRadius = 176

border-top-left-radius



BorderTopRightRadius = 177

border-top-right-radius



Bottom = 178

bottom



InsetBlockEnd = 179

inset-block-end



InsetBlockStart = 180

inset-block-start



InsetInlineEnd = 181

inset-inline-end



InsetInlineStart = 182

inset-inline-start



Left = 183

left



Right = 184

right



Top = 185

top



MarginBlockEnd = 186

margin-block-end



MarginBlockStart = 187

margin-block-start



MarginBottom = 188

margin-bottom



MarginInlineEnd = 189

margin-inline-end



MarginInlineStart = 190

margin-inline-start



MarginLeft = 191

margin-left



MarginRight = 192

margin-right



MarginTop = 193

margin-top



PaddingBlockEnd = 194

padding-block-end



PaddingBlockStart = 195

padding-block-start



PaddingBottom = 196

padding-bottom



PaddingInlineEnd = 197

padding-inline-end



PaddingInlineStart = 198

padding-inline-start



PaddingLeft = 199

padding-left



PaddingRight = 200

padding-right



PaddingTop = 201

padding-top



BlockSize = 202

block-size



Height = 203

height



InlineSize = 204

inline-size



MinBlockSize = 205

min-block-size



MinHeight = 206

min-height



MinInlineSize = 207

min-inline-size



MinWidth = 208

min-width



Width = 209

width



BorderBlockEndWidth = 210

border-block-end-width



BorderBlockStartWidth = 211

border-block-start-width



BorderBottomWidth = 212

border-bottom-width



BorderInlineEndWidth = 213

border-inline-end-width



BorderInlineStartWidth = 214

border-inline-start-width



BorderLeftWidth = 215

border-left-width



BorderRightWidth = 216

border-right-width



BorderTopWidth = 217

border-top-width



OutlineWidth = 218

outline-width



BackgroundColor = 219

background-color



BorderBlockEndColor = 220

border-block-end-color



BorderBlockStartColor = 221

border-block-start-color



BorderBottomColor = 222

border-bottom-color



BorderInlineEndColor = 223

border-inline-end-color



BorderInlineStartColor = 224

border-inline-start-color



BorderLeftColor = 225

border-left-color



BorderRightColor = 226

border-right-color



BorderTopColor = 227

border-top-color



OutlineColor = 228

outline-color



TextDecorationColor = 229

text-decoration-color

Implementations

Source

impl LonghandId

pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId>

Returns an iterator over all the shorthands that include this longhand.

pub(super) fn parse_value<'i, 't>( self, context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<PropertyDeclaration, ParseError<'i>>

fn logical_mapping_data(self) -> Option<&'static LogicalMappingData>

Return the relevant data to map a particular logical property into physical.

pub fn to_physical(self, wm: WritingMode) -> Self

If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.

pub fn logical_group(self) -> Option<LogicalGroupId>

Return the logical group of this longhand property.

pub fn flags(self) -> PropertyFlags

Returns PropertyFlags for given longhand property.

Source

impl LonghandId

pub fn name(&self) -> &'static str

Get the name of this longhand property.

pub fn inherited(self) -> bool

Returns whether the longhand property is inherited by default.

pub fn zoom_dependent(self) -> bool

Returns whether the longhand property is zoom-dependent.

pub fn ignored_when_document_colors_disabled(self) -> bool

Returns true if the property is one that is ignored when document colors are disabled.

pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool

Returns whether this longhand is non_custom or is a longhand of it.

pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool

Returns whether this longhand is a longhand of shorthand.

pub fn is_animatable(self) -> bool

Returns whether this property is animatable.

pub fn is_discrete_animatable(self) -> bool

Returns whether this property is animatable in a discrete way.

pub fn is_logical(self) -> bool

Return whether this property is logical.