LonghandId

Enum LonghandId 

#[repr(u16)]
pub enum LonghandId {
Show 228 variants AlignItems = 0, AlignmentBaseline = 1, AspectRatio = 2, BackfaceVisibility = 3, BaselineSource = 4, BorderCollapse = 5, BorderImageRepeat = 6, BoxSizing = 7, CaptionSide = 8, Clear = 9, ColumnCount = 10, ColumnSpan = 11, Contain = 12, ContainerType = 13, Direction = 14, Display = 15, EmptyCells = 16, FlexDirection = 17, FlexWrap = 18, Float = 19, FontLanguageOverride = 20, FontOpticalSizing = 21, FontStretch = 22, FontStyle = 23, FontSynthesisWeight = 24, FontVariantCaps = 25, FontWeight = 26, GridAutoFlow = 27, ImageRendering = 28, Isolation = 29, JustifyItems = 30, LineBreak = 31, ListStylePosition = 32, MixBlendMode = 33, ObjectFit = 34, Opacity = 35, Order = 36, OutlineStyle = 37, OverflowWrap = 38, PointerEvents = 39, Position = 40, PositionArea = 41, ServoOverflowClipBox = 42, ServoTopLayer = 43, TableLayout = 44, TextAlign = 45, TextAlignLast = 46, TextDecorationLine = 47, TextDecorationStyle = 48, TextJustify = 49, TextRendering = 50, TextTransform = 51, TextWrapMode = 52, TransformStyle = 53, UnicodeBidi = 54, Visibility = 55, WebkitTextSecurity = 56, WhiteSpaceCollapse = 57, WordBreak = 58, WritingMode = 59, ZIndex = 60, Zoom = 61, AlignContent = 62, JustifyContent = 63, FlexGrow = 64, FlexShrink = 65, AlignSelf = 66, JustifySelf = 67, OverflowBlock = 68, OverflowInline = 69, OverflowX = 70, OverflowY = 71, BorderBlockEndStyle = 72, BorderBlockStartStyle = 73, BorderBottomStyle = 74, BorderInlineEndStyle = 75, BorderInlineStartStyle = 76, BorderLeftStyle = 77, BorderRightStyle = 78, BorderTopStyle = 79, AnimationComposition = 80, AnimationDelay = 81, AnimationDirection = 82, AnimationDuration = 83, AnimationFillMode = 84, AnimationIterationCount = 85, AnimationName = 86, AnimationPlayState = 87, AnimationTimeline = 88, AnimationTimingFunction = 89, BackdropFilter = 90, BackgroundAttachment = 91, BackgroundClip = 92, BackgroundImage = 93, BackgroundOrigin = 94, BackgroundPositionX = 95, BackgroundPositionY = 96, BackgroundRepeat = 97, BackgroundSize = 98, BaselineShift = 99, BorderImageOutset = 100, BorderImageSlice = 101, BorderImageWidth = 102, BorderSpacing = 103, BoxShadow = 104, CaretColor = 105, Clip = 106, ClipPath = 107, Color = 108, ColorScheme = 109, ColumnWidth = 110, ContainerName = 111, Content = 112, CounterIncrement = 113, CounterReset = 114, Cursor = 115, Filter = 116, FlexBasis = 117, FontFamily = 118, FontSize = 119, FontVariationSettings = 120, GridTemplateAreas = 121, LetterSpacing = 122, LineHeight = 123, ListStyleType = 124, MaskImage = 125, OffsetPath = 126, OutlineOffset = 127, OverflowClipMargin = 128, Perspective = 129, PositionTryFallbacks = 130, Quotes = 131, Rotate = 132, Scale = 133, TextIndent = 134, TextOverflow = 135, TextShadow = 136, Transform = 137, TransformOrigin = 138, TransitionBehavior = 139, TransitionDelay = 140, TransitionDuration = 141, TransitionProperty = 142, TransitionTimingFunction = 143, Translate = 144, ViewTransitionClass = 145, ViewTransitionName = 146, WillChange = 147, WordSpacing = 148, XLang = 149, ObjectPosition = 150, PerspectiveOrigin = 151, GridTemplateColumns = 152, GridTemplateRows = 153, BorderImageSource = 154, ListStyleImage = 155, GridAutoColumns = 156, GridAutoRows = 157, ColumnGap = 158, RowGap = 159, GridColumnEnd = 160, GridColumnStart = 161, GridRowEnd = 162, GridRowStart = 163, MaxBlockSize = 164, MaxHeight = 165, MaxInlineSize = 166, MaxWidth = 167, BorderBottomLeftRadius = 168, BorderBottomRightRadius = 169, BorderEndEndRadius = 170, BorderEndStartRadius = 171, BorderStartEndRadius = 172, BorderStartStartRadius = 173, BorderTopLeftRadius = 174, BorderTopRightRadius = 175, Bottom = 176, InsetBlockEnd = 177, InsetBlockStart = 178, InsetInlineEnd = 179, InsetInlineStart = 180, Left = 181, Right = 182, Top = 183, MarginBlockEnd = 184, MarginBlockStart = 185, MarginBottom = 186, MarginInlineEnd = 187, MarginInlineStart = 188, MarginLeft = 189, MarginRight = 190, MarginTop = 191, PaddingBlockEnd = 192, PaddingBlockStart = 193, PaddingBottom = 194, PaddingInlineEnd = 195, PaddingInlineStart = 196, PaddingLeft = 197, PaddingRight = 198, PaddingTop = 199, BlockSize = 200, Height = 201, InlineSize = 202, MinBlockSize = 203, MinHeight = 204, MinInlineSize = 205, MinWidth = 206, Width = 207, BorderBlockEndWidth = 208, BorderBlockStartWidth = 209, BorderBottomWidth = 210, BorderInlineEndWidth = 211, BorderInlineStartWidth = 212, BorderLeftWidth = 213, BorderRightWidth = 214, BorderTopWidth = 215, OutlineWidth = 216, BackgroundColor = 217, BorderBlockEndColor = 218, BorderBlockStartColor = 219, BorderBottomColor = 220, BorderInlineEndColor = 221, BorderInlineStartColor = 222, BorderLeftColor = 223, BorderRightColor = 224, BorderTopColor = 225, OutlineColor = 226, TextDecorationColor = 227,
}
An identifier for a given longhand property.

Variants



AlignItems = 0

align-items



AlignmentBaseline = 1

alignment-baseline



AspectRatio = 2

aspect-ratio



BackfaceVisibility = 3

backface-visibility



BaselineSource = 4

baseline-source



BorderCollapse = 5

border-collapse



BorderImageRepeat = 6

border-image-repeat



BoxSizing = 7

box-sizing



CaptionSide = 8

caption-side



Clear = 9

clear



ColumnCount = 10

column-count



ColumnSpan = 11

column-span



Contain = 12

contain



ContainerType = 13

container-type



Direction = 14

direction



Display = 15

display



EmptyCells = 16

empty-cells



FlexDirection = 17

flex-direction



FlexWrap = 18

flex-wrap



Float = 19

float



FontLanguageOverride = 20

font-language-override



FontOpticalSizing = 21

font-optical-sizing



FontStretch = 22

font-stretch



FontStyle = 23

font-style



FontSynthesisWeight = 24

font-synthesis-weight



FontVariantCaps = 25

font-variant-caps



FontWeight = 26

font-weight



GridAutoFlow = 27

grid-auto-flow



ImageRendering = 28

image-rendering



Isolation = 29

isolation



JustifyItems = 30

justify-items



LineBreak = 31

line-break



ListStylePosition = 32

list-style-position



MixBlendMode = 33

mix-blend-mode



ObjectFit = 34

object-fit



Opacity = 35

opacity



Order = 36

order



OutlineStyle = 37

outline-style



OverflowWrap = 38

overflow-wrap



PointerEvents = 39

pointer-events



Position = 40

position



PositionArea = 41

position-area



ServoOverflowClipBox = 42

-servo-overflow-clip-box



ServoTopLayer = 43

-servo-top-layer



TableLayout = 44

table-layout



TextAlign = 45

text-align



TextAlignLast = 46

text-align-last



TextDecorationLine = 47

text-decoration-line



TextDecorationStyle = 48

text-decoration-style



TextJustify = 49

text-justify



TextRendering = 50

text-rendering



TextTransform = 51

text-transform



TextWrapMode = 52

text-wrap-mode



TransformStyle = 53

transform-style



UnicodeBidi = 54

unicode-bidi



Visibility = 55

visibility



WebkitTextSecurity = 56

-webkit-text-security



WhiteSpaceCollapse = 57

white-space-collapse



WordBreak = 58

word-break



WritingMode = 59

writing-mode



ZIndex = 60

z-index



Zoom = 61

zoom



AlignContent = 62

align-content



JustifyContent = 63

justify-content



FlexGrow = 64

flex-grow



FlexShrink = 65

flex-shrink



AlignSelf = 66

align-self



JustifySelf = 67

justify-self



OverflowBlock = 68

overflow-block



OverflowInline = 69

overflow-inline



OverflowX = 70

overflow-x



OverflowY = 71

overflow-y



BorderBlockEndStyle = 72

border-block-end-style



BorderBlockStartStyle = 73

border-block-start-style



BorderBottomStyle = 74

border-bottom-style



BorderInlineEndStyle = 75

border-inline-end-style



BorderInlineStartStyle = 76

border-inline-start-style



BorderLeftStyle = 77

border-left-style



BorderRightStyle = 78

border-right-style



BorderTopStyle = 79

border-top-style



AnimationComposition = 80

animation-composition



AnimationDelay = 81

animation-delay



AnimationDirection = 82

animation-direction



AnimationDuration = 83

animation-duration



AnimationFillMode = 84

animation-fill-mode



AnimationIterationCount = 85

animation-iteration-count



AnimationName = 86

animation-name



AnimationPlayState = 87

animation-play-state



AnimationTimeline = 88

animation-timeline



AnimationTimingFunction = 89

animation-timing-function



BackdropFilter = 90

backdrop-filter



BackgroundAttachment = 91

background-attachment



BackgroundClip = 92

background-clip



BackgroundImage = 93

background-image



BackgroundOrigin = 94

background-origin



BackgroundPositionX = 95

background-position-x



BackgroundPositionY = 96

background-position-y



BackgroundRepeat = 97

background-repeat



BackgroundSize = 98

background-size



BaselineShift = 99

baseline-shift



BorderImageOutset = 100

border-image-outset



BorderImageSlice = 101

border-image-slice



BorderImageWidth = 102

border-image-width



BorderSpacing = 103

border-spacing



BoxShadow = 104

box-shadow



CaretColor = 105

caret-color



Clip = 106

clip



ClipPath = 107

clip-path



Color = 108

color



ColorScheme = 109

color-scheme



ColumnWidth = 110

column-width



ContainerName = 111

container-name



Content = 112

content



CounterIncrement = 113

counter-increment



CounterReset = 114

counter-reset



Cursor = 115

cursor



Filter = 116

filter



FlexBasis = 117

flex-basis



FontFamily = 118

font-family



FontSize = 119

font-size



FontVariationSettings = 120

font-variation-settings



GridTemplateAreas = 121

grid-template-areas



LetterSpacing = 122

letter-spacing



LineHeight = 123

line-height



ListStyleType = 124

list-style-type



MaskImage = 125

mask-image



OffsetPath = 126

offset-path



OutlineOffset = 127

outline-offset



OverflowClipMargin = 128

overflow-clip-margin



Perspective = 129

perspective



PositionTryFallbacks = 130

position-try-fallbacks



Quotes = 131

quotes



Rotate = 132

rotate



Scale = 133

scale



TextIndent = 134

text-indent



TextOverflow = 135

text-overflow



TextShadow = 136

text-shadow



Transform = 137

transform



TransformOrigin = 138

transform-origin



TransitionBehavior = 139

transition-behavior



TransitionDelay = 140

transition-delay



TransitionDuration = 141

transition-duration



TransitionProperty = 142

transition-property



TransitionTimingFunction = 143

transition-timing-function



Translate = 144

translate



ViewTransitionClass = 145

view-transition-class



ViewTransitionName = 146

view-transition-name



WillChange = 147

will-change



WordSpacing = 148

word-spacing



XLang = 149

-x-lang



ObjectPosition = 150

object-position



PerspectiveOrigin = 151

perspective-origin



GridTemplateColumns = 152

grid-template-columns



GridTemplateRows = 153

grid-template-rows



BorderImageSource = 154

border-image-source



ListStyleImage = 155

list-style-image



GridAutoColumns = 156

grid-auto-columns



GridAutoRows = 157

grid-auto-rows



ColumnGap = 158

column-gap



RowGap = 159

row-gap



GridColumnEnd = 160

grid-column-end



GridColumnStart = 161

grid-column-start



GridRowEnd = 162

grid-row-end



GridRowStart = 163

grid-row-start



MaxBlockSize = 164

max-block-size



MaxHeight = 165

max-height



MaxInlineSize = 166

max-inline-size



MaxWidth = 167

max-width



BorderBottomLeftRadius = 168

border-bottom-left-radius



BorderBottomRightRadius = 169

border-bottom-right-radius



BorderEndEndRadius = 170

border-end-end-radius



BorderEndStartRadius = 171

border-end-start-radius



BorderStartEndRadius = 172

border-start-end-radius



BorderStartStartRadius = 173

border-start-start-radius



BorderTopLeftRadius = 174

border-top-left-radius



BorderTopRightRadius = 175

border-top-right-radius



Bottom = 176

bottom



InsetBlockEnd = 177

inset-block-end



InsetBlockStart = 178

inset-block-start



InsetInlineEnd = 179

inset-inline-end



InsetInlineStart = 180

inset-inline-start



Left = 181

left



Right = 182

right



Top = 183

top



MarginBlockEnd = 184

margin-block-end



MarginBlockStart = 185

margin-block-start



MarginBottom = 186

margin-bottom



MarginInlineEnd = 187

margin-inline-end



MarginInlineStart = 188

margin-inline-start



MarginLeft = 189

margin-left



MarginRight = 190

margin-right



MarginTop = 191

margin-top



PaddingBlockEnd = 192

padding-block-end



PaddingBlockStart = 193

padding-block-start



PaddingBottom = 194

padding-bottom



PaddingInlineEnd = 195

padding-inline-end



PaddingInlineStart = 196

padding-inline-start



PaddingLeft = 197

padding-left



PaddingRight = 198

padding-right



PaddingTop = 199

padding-top



BlockSize = 200

block-size



Height = 201

height



InlineSize = 202

inline-size



MinBlockSize = 203

min-block-size



MinHeight = 204

min-height



MinInlineSize = 205

min-inline-size



MinWidth = 206

min-width



Width = 207

width



BorderBlockEndWidth = 208

border-block-end-width



BorderBlockStartWidth = 209

border-block-start-width



BorderBottomWidth = 210

border-bottom-width



BorderInlineEndWidth = 211

border-inline-end-width



BorderInlineStartWidth = 212

border-inline-start-width



BorderLeftWidth = 213

border-left-width



BorderRightWidth = 214

border-right-width



BorderTopWidth = 215

border-top-width



OutlineWidth = 216

outline-width



BackgroundColor = 217

background-color



BorderBlockEndColor = 218

border-block-end-color



BorderBlockStartColor = 219

border-block-start-color



BorderBottomColor = 220

border-bottom-color



BorderInlineEndColor = 221

border-inline-end-color



BorderInlineStartColor = 222

border-inline-start-color



BorderLeftColor = 223

border-left-color



BorderRightColor = 224

border-right-color



BorderTopColor = 225

border-top-color



OutlineColor = 226

outline-color



TextDecorationColor = 227

text-decoration-color

Implementations

Source

impl LonghandId

pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId>

Returns an iterator over all the shorthands that include this longhand.

pub(super) fn parse_value<'i, 't>( self, context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<PropertyDeclaration, ParseError<'i>>

fn logical_mapping_data(self) -> Option<&'static LogicalMappingData>

Return the relevant data to map a particular logical property into physical.

pub fn to_physical(self, wm: WritingMode) -> Self

If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.

pub fn logical_group(self) -> Option<LogicalGroupId>

Return the logical group of this longhand property.

pub fn flags(self) -> PropertyFlags

Returns PropertyFlags for given longhand property.

Source

impl LonghandId

pub fn name(&self) -> &'static str

Get the name of this longhand property.

pub fn inherited(self) -> bool

Returns whether the longhand property is inherited by default.

pub fn zoom_dependent(self) -> bool

Returns whether the longhand property is zoom-dependent.

pub fn ignored_when_document_colors_disabled(self) -> bool

Returns true if the property is one that is ignored when document colors are disabled.

pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool

Returns whether this longhand is non_custom or is a longhand of it.

pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool

Returns whether this longhand is a longhand of shorthand.

pub fn is_animatable(self) -> bool

Returns whether this property is animatable.

pub fn is_discrete_animatable(self) -> bool

Returns whether this property is animatable in a discrete way.

pub fn is_logical(self) -> bool

Return whether this property is logical.